(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     90503,       2439]*)
(*NotebookOutlinePosition[     92201,       2492]*)
(*  CellTagsIndexPosition[     92157,       2488]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "\nPr\[AAcute]cticas de Matem\[AAcute]ticas con ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ."
}], "Title",
  CellMargins->{{17, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  AspectRatioFixed->True,
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]],

Cell["\<\

M\[EAcute]todos Num\[EAcute]ricos 

 Pr\[AAcute]ctica n\.ba 6.  Interpolaci\[OAcute]n spline.
\
\>", "Subtitle",
  CellFrame->True,
  CellMargins->{{17, 1}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{13, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  AspectRatioFixed->True,
  Background->GrayLevel[0.900008]],

Cell[TextData[StyleBox[
"Departamento de  Matem\[AAcute]tica Aplicada.\n\nE.T.S. de \
Ingenier\[IAcute]a Industrial de B\[EAcute]jar\n\nUniversidad de Salamanca"]],
   "Text",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  AspectRatioFixed->True,
  FontColor->GrayLevel[1],
  Background->RGBColor[0, 0, 1]],

Cell["Introducci\[OAcute]n.", "Section",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
\tComo es sabido, cuando el n\[UAcute]mero de puntos es elevado, es habitual \
acudir a las t\[EAcute]cnicas de interpolaci\[OAcute]n a trozos, como ya \
vimos en la pr\[AAcute]ctica correspondiente. Para garantizar suficientes \
condiciones de continuidad y derivabilidad en las uniones, uno de los m\
\[EAcute]todos m\[AAcute]s utilizados es la interpolaci\[OAcute]n spline que \
se realiza, de muy diferentes formas, mediante polinomios c\[UAcute]bicos en \
cada subintervalo.\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["La interpolaci\[OAcute]n spline.", "Section",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\tEl problema de la interpolaci\[OAcute]n spline puede plantearse de la \
siguiente manera. Dada una tabla de valores (",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_i, \)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(y\_i)\)\)]],
  " ,0\[LessEqual]i\[LessEqual]n , S es un ",
  StyleBox["spline natural ",
    FontWeight->"Bold"],
  "si se verifican las siguientes condiciones:\n1.- La restricci\[OAcute]n de \
S a cada intervalo [",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_i, x\_\(i + 1\)]\)\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`S\_i\)]],
  ", es un polinomio c\[UAcute]bico.\n2.- En los puntos de uni\[OAcute]n, las \
restricciones coinciden, es decir, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(S\_\(i + 1\)\)(x\_\(i + 1\)) = \ \(S\_i\)(x\_\(i + 1\))\)]],
  ".\n3.- En los puntos de uni\[OAcute]n, las derivadas de las restricciones \
coinciden, es decir, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\((S')\)\_\(i + 1\)\) \((x\_\(i + 1\))\) = \ 
        \(\((S')\)\_i\) \((x\_\(i + 1\))\)\)]],
  ".\n4.- En los puntos de uni\[OAcute]n, las derivadas segundas de las \
restricciones coinciden, es decir, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\((\(S'\)')\)\_\(i + 1\)\) \((x\_\(i + 1\))\) = \ 
        \(\((\(S'\)')\)\_i\) \((x\_\(i + 1\))\)\)]],
  ".\n5.- La funci\[OAcute]n S es interpoladora, es decir, verifica la tabla \
de valores inicial ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ \(S\_i\)(x\_i) = y\_i, \ \ 
      \(S\_\(n - 1\)\)(x\_n) = \(y\_n.\)\)\)]],
  "\n6.- En la frontera, las derivadas segundas se anulan, es decir, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\((\(S'\)')\)\_0\) \((x\_0)\) = \ 
        \(\(\((\(S'\)')\)\_\(n - 1\)\) \((x\_n)\) = 0.\)\)]],
  "\n"
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\tLas condiciones anteriores determinan de manera \[UAcute]nica a la funci\
\[OAcute]n S. Las condiciones finales sobre la derivada segunda en los puntos \
de interpolaci\[OAcute]n frontera pueden variarse dando lugar a diferentes \
tipos de splines: de frontera fija, etc. Nos ocupamos \[UAcute]nicamente de \
los splines naturales definidos por las condiciones enumeradas anteriormente.\
\n\tSeg\[UAcute]n el desarrollo te\[OAcute]rico realizado en clase, si \
escribimos ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\ 
      \(S\_i\)(x) = \ 
        a\_i + \ b\_i\ \((x - \ x\_i)\) + c\_i\ \((x - \ x\_i)\)\^2 + \ 
          d\_i\ \((x - \ x\_i)\)\^3\)\)]]],
  " ,  ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(h\_i = x\_\(i + 1\) - x\_i\ , \)\)]]],
  " la determinaci\[OAcute]n de los coeficientes de ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\ S\_i\)\)]]],
  " depende de la soluci\[OAcute]n del sistema tridiagonal (escrito en forma \
matricial):"
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"(", GridBox[{
                  {"1", "0", "0", ".", ".", ".", "0"},
                 
                   {\(h\_0\), \(2 \((h\_1 + h\_0)\)\), \(h\_1\), "0", ".", 
                    ".", "0"},
                 
                   {"0", \(h\_1\), \(2 \((h\_2 + h\_1)\)\), \(h\_2\), "0", 
                    ".", "0"},
                 
                   {"0", "0", \(h\_2\), \(2 \((h\_3 + h\_2)\)\), \(h\_3\), 
                    ".", "0"},
                  {".", ".", ".", ".", ".", ".", "."},
                 
                   {"0", "0", ".", ".", \(h\_\(n - 2\)\), 
                    \(2 \((h\_\(n - 1\) + h\_\(n - 2\))\)\), 
                    \(h\_\(n - 1\)\)},
                  {"0", "0", "0", ".", ".", "0", "1"}
                  }], ")"}], " ", 
            RowBox[{"(", GridBox[{
                  {\(c\_0\)},
                  {\(c\_1\)},
                  {\(c\_2\)},
                  {"."},
                  {"."},
                  {"."},
                  {\(c\_n\)}
                  }], ")"}]}], "=", "\n", "\t", 
          RowBox[{"(", GridBox[{
                {"0"},
               
                 {\(\(3\/h\_1\) \((a\_2 - a\_1)\) - 
                    \(3\/h\_0\) \((a\_1 - a\_0)\)\)},
               
                 {\(\(3\/h\_2\) \((a\_3 - a\_2)\) - 
                    \(3\/h\_1\) \((a\_2 - a\_1)\)\)},
                {"."},
                {"."},
               
                 {\(\(3\/h\_\(n - 1\)\) \((a\_n - a\_\(n - 1\))\) - 
                    \(3\/h\_\(n - 2\)\) \((a\_\(n - 1\) - a\_\(n - 2\))\)\)},
                {"0"}
                }], ")"}]}], TraditionalForm]]]]
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tUna vez conocidos los coeficientes ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " (resolviendo el sistema anterior), el resto de los coeficientes se \
conocen a trav\[EAcute]s de las relaciones\n ",
  Cell[BoxData[
      \(TraditionalForm\`\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ 
      b\_i = \(1\/h\_i\) \((a\_\(i + 1\) - a\_i)\) - 
          \(h\_i\/3\) \((c\_\(i + 1\) + 2  c\_i)\)\ , \ 
      d\_i = \(c\_\(i + 1\) - c\_i\)\/\(3  h\_i\)\ , \)\)]],
  "\n mientras que los coeficientes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\ a\_i\)\)]],
  " son conocidos a trav\[EAcute]s de la tabla de valores, por el \
car\[AAcute]cter interpolador del spline."
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tPara codificar correctamente este algoritmo en ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " necesitamos, adem\[AAcute]s de acudir al manejo de listas habitual, \
utilizar un paquete de ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " que contiene la instrucci\[OAcute]n ",
  StyleBox["TridiagonalSolve",
    FontWeight->"Bold"],
  ", que resuelve f\[AAcute]cilmente los sistemas tridiagonales."
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<LinearAlgebra`Tridiagonal`\>"]\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\tLa funci\[OAcute]n ",
  StyleBox["Espline",
    FontWeight->"Bold"],
  " que definimos a continuaci\[OAcute]n  contiene la traducci\[OAcute]n a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " de los c\[AAcute]lculos efectuados anteriormente hasta llegar a la soluci\
\[OAcute]n del sistema tridiagonal planteado:"
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Espline[xx_List, yy_List, x_] := \n\t
      Module[{n = Length[xx], h, a = yy, b, c, dp, di, ds, sol}, \n\t\t
        h = Table[xx[\([i + 1]\)] - xx[\([i]\)], {i, n - 1}]; \n\t\t
        dp = Table[2 \((h[\([i]\)] + h[\([i + 1]\)])\), {i, n - 2}]; \n\t\t
        AppendTo[dp, 1]; PrependTo[dp, 1]; \n\t\t
        di = ReplacePart[h, 0, n - 1]; \n\t\tds = ReplacePart[h, 0, 1]; \n\t\t
        bb = Table[
            3 \((a[\([i + 1]\)] - a[\([i]\)])\)/h[\([i]\)]\n\t\t\t\t\t - 
              3 \((a[\([i]\)] - a[\([i - 1]\)])\)/h[\([i - 1]\)], {i, 2, 
              n - 1}]; \n\t\t\t\tAppendTo[bb, 0]; PrependTo[bb, 0]; \n\t\t
        c = TridiagonalSolve[di, dp, ds, bb]; \n\t\t
        b = Table[
            \((a[\([i + 1]\)] - a[\([i]\)])\)/h[\([i]\)]\n\t\t\t\t\t - 
              h[\([i]\)]\ \((2\ \ c[\([i]\)] + c[\([i + 1]\)])\)/3\n
            \t\t\t\t\t\t, {i, n - 1}]; \n\t\t
        d = Table[\((c[\([i + 1]\)] - c[\([i]\)])\)/\((3\ \ h[\([i]\)])\)\n
            \t\t\t\t\t, {i, n - 1}]; \n\t\t
        sol = Table[
            a[\([i]\)] + b[\([i]\)]\ \((x - xx[\([i]\)])\) + \n\t\t\t\t\t
              c[\([i]\)]\ \((x - xx[\([i]\)])\)^2 + 
              d[\([i]\)]\ \((x - xx[\([i]\)])\)^3, {i, n - 1}]]\n\t\t\n\t\t
    \)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\n\tLa funci\[OAcute]n",
  StyleBox[" Espline",
    FontWeight->"Bold"],
  " utiliza como argumentos las listas correspondientes a los valores de la \
tabla a interpolar y la variable que vamos a utilizar como variable de los \
polinomios en cada subintervalo. La salida de la funci\[OAcute]n es una lista \
que contiene los polinomios c\[UAcute]bicos calculados."
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "  ",
  StyleBox["Ejemplo  1:",
    FontVariations->{"Underline"->True}],
  " "
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
\tCalcular el  spline natural asociado a la tabla de valores  \
{0,1},{1,0},{2,0.5},{3,1}.
\
\>", "Text",
  CellDingbat->None,
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
\tPara calcular la lista de los polinomios c\[UAcute]bicos pedida, no tenemos \
m\[AAcute]s que aplicar la funci\[OAcute]n que hemos definido:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(p = Espline[{0, 1, 2, 3}, {1, 0, 1/2, 1}, x]\)], "Input"],

Cell[BoxData[
    \({1 - \(7\ x\)\/5 + \(2\ x\^3\)\/5, 
      \(1 - x\)\/5 + 6\/5\ \((\(-1\) + x)\)\^2 - 1\/2\ \((\(-1\) + x)\)\^3, 
      1\/2 + 7\/10\ \((\(-2\) + x)\) - 3\/10\ \((\(-2\) + x)\)\^2 + 
        1\/10\ \((\(-2\) + x)\)\^3}\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell["\<\
\tLos polinomios pueden ser recuperados f\[AAcute]cilmente de la lista \
hallada utilizando la t\[EAcute]cnica habitual:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol1 = Expand[p[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(1 - \(7\ x\)\/5 + \(2\ x\^3\)\/5\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol2 = Expand[p[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(19\/10 - \(41\ x\)\/10 + \(27\ x\^2\)\/10 - x\^3\/2\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol3 = Expand[p[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-\(29\/10\)\) + \(31\ x\)\/10 - \(9\ x\^2\)\/10 + x\^3\/10\)], 
  "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell["\<\
\tPodemos definir la funci\[OAcute]n spline natural de acuerdo con las \
siguientes instrucciones:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(s1[t_] := pol1 /. x -> t; \ns2[t_] := pol2 /. x -> t; \n
    s3[t_] := pol3 /. x -> t; \)], "Input"],

Cell[BoxData[
    \(\(S[x_] := s1[x] /; 0 \[LessEqual] x \[LessEqual] 1; \n
    S[x_] := s2[x] /; 1 \[LessEqual] x \[LessEqual] 2; \n
    S[x_] := s3[x] /; 2 \[LessEqual] x \[LessEqual] 3; \n\)\)], "Input"],

Cell["\tLa representaci\[OAcute]n gr\[AAcute]fica es:", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[S[x], {x, 0, 3}, PlotStyle -> RGBColor[1, 0, 0], 
      AspectRatio -> Automatic]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33622 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0107505 0.31746 [
[.18254 -0.00175 -9 -9 ]
[.18254 -0.00175 9 0 ]
[.34127 -0.00175 -3 -9 ]
[.34127 -0.00175 3 0 ]
[.5 -0.00175 -9 -9 ]
[.5 -0.00175 9 0 ]
[.65873 -0.00175 -3 -9 ]
[.65873 -0.00175 3 0 ]
[.81746 -0.00175 -9 -9 ]
[.81746 -0.00175 9 0 ]
[.97619 -0.00175 -3 -9 ]
[.97619 -0.00175 3 0 ]
[.01131 .07424 -18 -4.5 ]
[.01131 .07424 0 4.5 ]
[.01131 .13773 -18 -4.5 ]
[.01131 .13773 0 4.5 ]
[.01131 .20123 -18 -4.5 ]
[.01131 .20123 0 4.5 ]
[.01131 .26472 -18 -4.5 ]
[.01131 .26472 0 4.5 ]
[.01131 .32821 -6 -4.5 ]
[.01131 .32821 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33622 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .01075 m
.18254 .017 L
s
[(0.5)] .18254 -0.00175 0 1 Mshowa
.34127 .01075 m
.34127 .017 L
s
[(1)] .34127 -0.00175 0 1 Mshowa
.5 .01075 m
.5 .017 L
s
[(1.5)] .5 -0.00175 0 1 Mshowa
.65873 .01075 m
.65873 .017 L
s
[(2)] .65873 -0.00175 0 1 Mshowa
.81746 .01075 m
.81746 .017 L
s
[(2.5)] .81746 -0.00175 0 1 Mshowa
.97619 .01075 m
.97619 .017 L
s
[(3)] .97619 -0.00175 0 1 Mshowa
.125 Mabswid
.05556 .01075 m
.05556 .0145 L
s
.0873 .01075 m
.0873 .0145 L
s
.11905 .01075 m
.11905 .0145 L
s
.15079 .01075 m
.15079 .0145 L
s
.21429 .01075 m
.21429 .0145 L
s
.24603 .01075 m
.24603 .0145 L
s
.27778 .01075 m
.27778 .0145 L
s
.30952 .01075 m
.30952 .0145 L
s
.37302 .01075 m
.37302 .0145 L
s
.40476 .01075 m
.40476 .0145 L
s
.43651 .01075 m
.43651 .0145 L
s
.46825 .01075 m
.46825 .0145 L
s
.53175 .01075 m
.53175 .0145 L
s
.56349 .01075 m
.56349 .0145 L
s
.59524 .01075 m
.59524 .0145 L
s
.62698 .01075 m
.62698 .0145 L
s
.69048 .01075 m
.69048 .0145 L
s
.72222 .01075 m
.72222 .0145 L
s
.75397 .01075 m
.75397 .0145 L
s
.78571 .01075 m
.78571 .0145 L
s
.84921 .01075 m
.84921 .0145 L
s
.88095 .01075 m
.88095 .0145 L
s
.9127 .01075 m
.9127 .0145 L
s
.94444 .01075 m
.94444 .0145 L
s
.25 Mabswid
0 .01075 m
1 .01075 L
s
.02381 .07424 m
.03006 .07424 L
s
[(0.2)] .01131 .07424 1 0 Mshowa
.02381 .13773 m
.03006 .13773 L
s
[(0.4)] .01131 .13773 1 0 Mshowa
.02381 .20123 m
.03006 .20123 L
s
[(0.6)] .01131 .20123 1 0 Mshowa
.02381 .26472 m
.03006 .26472 L
s
[(0.8)] .01131 .26472 1 0 Mshowa
.02381 .32821 m
.03006 .32821 L
s
[(1)] .01131 .32821 1 0 Mshowa
.125 Mabswid
.02381 .02662 m
.02756 .02662 L
s
.02381 .0425 m
.02756 .0425 L
s
.02381 .05837 m
.02756 .05837 L
s
.02381 .09012 m
.02756 .09012 L
s
.02381 .10599 m
.02756 .10599 L
s
.02381 .12186 m
.02756 .12186 L
s
.02381 .15361 m
.02756 .15361 L
s
.02381 .16948 m
.02756 .16948 L
s
.02381 .18535 m
.02756 .18535 L
s
.02381 .2171 m
.02756 .2171 L
s
.02381 .23297 m
.02756 .23297 L
s
.02381 .24885 m
.02756 .24885 L
s
.02381 .28059 m
.02756 .28059 L
s
.02381 .29646 m
.02756 .29646 L
s
.02381 .31234 m
.02756 .31234 L
s
.25 Mabswid
.02381 0 m
.02381 .33622 L
s
0 0 m
1 0 L
1 .33622 L
0 .33622 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .32821 m
.06244 .27435 L
.10458 .21722 L
.14415 .16665 L
.18221 .12223 L
.22272 .08098 L
.26171 .04859 L
.28158 .03531 L
.30316 .02364 L
.31323 .01924 L
.32392 .01534 L
.33393 .01242 L
.34309 .0104 L
.34791 .00959 L
.3525 .00897 L
.35734 .00849 L
.36008 .00829 L
.3613 .00822 L
.36262 .00816 L
.36387 .0081 L
.36501 .00807 L
.36611 .00804 L
.36727 .00802 L
.3683 .00801 L
.36927 .00801 L
.37034 .00801 L
.37148 .00802 L
.37269 .00804 L
.37401 .00808 L
.37526 .00812 L
.37642 .00818 L
.38092 .00845 L
.38334 .00866 L
.38555 .00888 L
.39055 .00948 L
.39958 .01096 L
.40962 .01316 L
.42019 .01607 L
.43993 .02305 L
.45829 .03116 L
.49734 .05275 L
.53884 .08052 L
.57882 .11004 L
.61729 .1392 L
.6582 .16911 L
.69761 .19533 L
.7355 .2181 L
.77584 .24009 L
.81466 .25942 L
.85594 .27838 L
Mistroke
.8957 .2955 L
.93394 .31124 L
.97464 .32759 L
.97619 .32821 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{390.375, 131.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000PaP00`40o`000?l0003oooooohOoool0
05?oool00`000?ooooooo`02oooo00<0003oooooool00_ooo`030000oooooooo02ooool50000;_oo
o`D00002oooo00<0003oooooool00_ooo`030000oooooooo02ooool30000<?ooo`<00003oooo00<0
003oooooool00_ooo`030000oooooooo02ooool200005?ooo`00D_ooo`030000oooo000000Ooool0
0`000?ooo`00000boooo00<0003oooooool0<?ooo`030000oooooooo00Koool00`000?ooo`00000`
oooo00<0003oooooool0<?ooo`030000oooooooo00Ooool00`000?ooo`00000boooo00<0003ooooo
ool04Oooo`00D_ooo`030000oooo000000Woool00`000?ooooooo`0`oooo00<0003oooooool0<?oo
o`030000oooooooo00Soool00`000?ooooooo`0_oooo00<0003oooooool0<?ooo`030000oooooooo
00Soool00`000?ooooooo`0_oooo00<0003oooooool04_ooo`00D_ooo`030000oooo000000Ooool2
0000<oooo`030000oooooooo033oool00`000?ooooooo`06oooo0P0003;oool00`000?ooooooo`0`
oooo00<0003oooooool01_ooo`80000coooo00<0003oooooool04Oooo`00D_ooo`030000oooo0000
00Ooool00`000?ooooooo`0boooo00<0003oooooool0<?ooo`030000oooooooo00Koool00`000?oo
ooooo`0`oooo00<0003oool00000<?ooo`030000oooo000000Ooool00`000?ooooooo`0`oooo00<0
003oool000004oooo`00Doooo`030000oooooooo00Koool30000<Oooo`80000aoooo0P0000Soool3
0000<Oooo`030000oooooooo033oool00`000?ooooooo`06oooo0`00037oool00`000?ooooooo`0B
oooo003oooooQoooo`00ooooohOoool00?oooon7oooo000Qoooo00<0003oooooool0ooooof?oool0
027oool00`000?ooooooo`3oooooHoooo`008Oooo`030000oooooooo0?oooomSoooo000Qoooo00<0
003oooooool0Kooooa7o003Roooo000HooooM@0000Ko000A00001?l00=<0000;oooo000Qoooo00<0
003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02Ooo
o`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo
00Woool00`000?ooooooo`08oooo00<0003oooooool00_ooo`;o0004oooo00<0003oooooool02?oo
o`030000oooooooo00Soool010000?l00?l00?l000Soool00`000?ooooooo`08oooo00<0003ooooo
ool02?ooo`030000oooooooo00Soool00`000?ooooooo`09oooo00<0003oooooool02?ooo`030000
oooooooo00Soool00`000?ooooooo`08oooo00<0003oooooool02Oooo`030000oooooooo00Soool0
0`000?ooooooo`08oooo00<0003oooooool02?ooo`030000oooooooo00Woool00`000?ooooooo`08
oooo00<0003oooooool02?ooo`030000oooooooo00Soool00`000?ooooooo`08oooo00<0003ooooo
ool02Oooo`030000oooooooo017oool0027oool00`000?ooooooo`0eoooo00<0003oooooool0;Ooo
o`;o0006oooo00<0003oooooool05oooo`Co000Joooo00<0003oooooool0=Oooo`030000oooooooo
03Koool00`000?ooooooo`0eoooo00<0003oooooool04Oooo`008Oooo`030000oooooooo06;oool3
o`009_ooo`Co003Coooo000Qoooo00<0003oooooool0H?ooo`;o000]oooo0_l00=7oool0027oool2
0000Goooo`;o000aoooo0_l00<ooool0027oool00`000?ooooooo`1Loooo0_l003Goool2o`00cOoo
o`008Oooo`030000oooooooo05[oool2o`00>Oooo`;o003;oooo000Qoooo00<0003oooooool0F?oo
o`;o000moooo0_l00<Woool0027oool00`000?ooooooo`1Foooo0_l0047oool2o`00aoooo`008Ooo
o`030000oooooooo05Goool00ol00?ooooooo`13oooo0_l00<Goool0027oool20000EOooo`03o`00
oooooooo04Koool00ol00?ooooooo`32oooo000Qoooo00<0003oooooool0D_ooo`;o001:oooo0_l0
0<;oool0027oool00`000?ooooooo`1Aoooo00?o003oooooool0C?ooo`;o0030oooo000Qoooo00<0
003oooooool0D?ooo`03o`00oooooooo04ooool2o`00__ooo`008Oooo`030000oooooooo04ooool0
0ol00?ooooooo`1Boooo00?o003oooooool0^oooo`008Oooo`030000oooooooo04goool2o`00E_oo
o`;o002koooo000Qoooo0P0004goool00ol00?ooooooo`1Hoooo0_l00;Woool0027oool00`000?oo
ooooo`1;oooo00?o003oooooool0Foooo`03o`00oooooooo0;Koool0027oool00`000?ooooooo`1:
oooo00?o003oooooool0GOooo`;o002foooo000?oooo00<0003oooooool00_ooo`040000oooooooo
oooo0`0000Koool00`000?ooooooo`19oooo00?o003oooooool0H?ooo`;o002doooo000>oooo00<0
003oool000001oooo`030000oooooooo00Koool00`000?ooooooo`18oooo00?o003oooooool0Hooo
o`03o`00oooooooo0;7oool000koool00`000?ooo`000008oooo00<0003oooooool01Oooo`<00016
oooo0_l006Ooool2o`00/Oooo`003_ooo`030000oooo000000Soool00`000?ooooooo`05oooo00<0
003oooooool0AOooo`03o`00oooooooo06Woool2o`00[oooo`003_ooo`030000oooo000000Ooool0
0`000?ooo`000006oooo00<0003oooooool0A?ooo`03o`00oooooooo06coool00ol00?ooooooo`2/
oooo000?oooo00<0003oooooool01oooo`030000oooooooo00Goool00`000?ooooooo`13oooo00?o
003oooooool0K_ooo`03o`00oooooooo0:_oool0027oool00`000?ooooooo`12oooo00?o003ooooo
ool0L?ooo`;o002[oooo000Qoooo00<0003oooooool0@Oooo`03o`00oooooooo07?oool00ol00?oo
ooooo`2Xoooo000Qoooo0P00047oool00ol00?ooooooo`1eoooo00?o003oooooool0Yoooo`008Ooo
o`030000oooooooo03ooool00ol00?ooooooo`1goooo00?o003oooooool0Y_ooo`008Oooo`030000
oooooooo03koool00ol00?ooooooo`1ioooo0_l00:Koool0027oool00`000?ooooooo`0moooo00?o
003oooooool0O?ooo`03o`00oooooooo0:?oool0027oool00`000?ooooooo`0loooo00?o003ooooo
ool0O_ooo`03o`00oooooooo0:;oool0027oool20000??ooo`03o`00oooooooo083oool2o`00X_oo
o`008Oooo`030000oooooooo03[oool00ol00?ooooooo`23oooo00?o003oooooool0Woooo`008Ooo
o`030000oooooooo03Woool00ol00?ooooooo`25oooo00?o003oooooool0W_ooo`008Oooo`030000
oooooooo03Soool00ol00?ooooooo`27oooo0_l009koool0027oool00`000?ooooooo`0goooo00?o
003oooooool0R_ooo`03o`00oooooooo09_oool0027oool00`000?ooooooo`0foooo00?o003ooooo
ool0S?ooo`03o`00oooooooo09[oool0027oool20000=_ooo`03o`00oooooooo08koool2o`00V_oo
o`008Oooo`030000oooooooo03Coool00ol00?ooooooo`2Aoooo00?o003oooooool0Uoooo`008Ooo
o`030000oooooooo03?oool00ol00?ooooooo`2Coooo0_l009Ooool0027oool00`000?ooooooo`0b
oooo00?o003oooooool0U_ooo`03o`00oooooooo09Coool000ooool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`<00005oooo00<0003oooooool0<Oooo`03o`00oooooooo09Soool00ol00?oo
ooooo`2Coooo000>oooo00<0003oool000002Oooo`030000oooooooo00Coool00`000?ooooooo`0a
oooo00?o003oooooool0VOooo`;o002Coooo000>oooo00<0003oool000001oooo`@00005oooo0`00
033oool00ol00?ooooooo`2Loooo00?o003oooooool0T?ooo`003_ooo`030000oooo000000Ooool0
0`000?ooo`000006oooo00<0003oooooool0;oooo`03o`00oooooooo09koool00ol00?ooooooo`2?
oooo000>oooo00<0003oool000002?ooo`800006oooo00<0003oooooool0;_ooo`03o`00oooooooo
0:3oool2o`00Soooo`003oooo`030000oooooooo00Soool00`000?ooooooo`04oooo00<0003ooooo
ool0;Oooo`03o`00oooooooo0:?oool00ol00?ooooooo`2<oooo000Qoooo00<0003oooooool0;?oo
o`03o`00oooooooo0:Goool00ol00?ooooooo`2;oooo000Qoooo0P0002coool00ol00?ooooooo`2W
oooo00?o003oooooool0R_ooo`008Oooo`030000oooooooo02[oool00ol00?ooooooo`2Yoooo0_l0
08[oool0027oool00`000?ooooooo`0Zoooo00?o003oooooool0Zoooo`03o`00oooooooo08Ooool0
027oool00`000?ooooooo`0Yoooo00?o003oooooool0[Oooo`03o`00oooooooo08Koool0027oool0
0`000?ooooooo`0Xoooo00?o003oooooool0[oooo`;o0026oooo000Qoooo00<0003oooooool09ooo
o`03o`00oooooooo0;;oool00ol00?ooooooo`23oooo000Qoooo0P0002Ooool00ol00?ooooooo`2d
oooo00?o003oooooool0P_ooo`008Oooo`030000oooooooo02Goool00ol00?ooooooo`2foooo0_l0
08;oool0027oool00`000?ooooooo`0Uoooo00?o003oooooool0^?ooo`03o`00oooooooo07ooool0
027oool00`000?ooooooo`0Toooo00?o003oooooool0^_ooo`;o001ooooo000Qoooo00<0003ooooo
ool08oooo`03o`00oooooooo0;goool00ol00?ooooooo`1loooo000Qoooo0P0002?oool00ol00?oo
ooooo`2ooooo0_l007coool0027oool00`000?ooooooo`0Roooo00?o003oooooool0`Oooo`;o001j
oooo000Qoooo00<0003oooooool08Oooo`03o`00oooooooo0<Coool00ol00?ooooooo`1goooo000Q
oooo00<0003oooooool08?ooo`03o`00oooooooo0<Koool2o`00Moooo`003oooo`030000oooooooo
00;oool010000?ooooooooooo`800007oooo00<0003oooooool07oooo`03o`00oooooooo0<Woool0
0ol00?ooooooo`1doooo000>oooo00<0003oool000001oooo`030000oooo000000Koool00`000?oo
ooooo`0Noooo00?o003oooooool0boooo`;o001doooo000>oooo00<0003oool000001oooo`030000
oooo000000Koool300007_ooo`03o`00oooooooo0<goool2o`00L_ooo`003_ooo`030000oooo0000
00Ooool200001oooo`030000oooooooo01goool00ol00?ooooooo`3@oooo0_l0073oool000koool0
0`000?ooo`000007oooo00<0003oooooool01_ooo`030000oooooooo01coool00ol00?ooooooo`3C
oooo00?o003oooooool0KOooo`003oooo`030000oooooooo00Ooool200001_ooo`030000oooooooo
01_oool00ol00?ooooooo`3Eoooo0_l006goool0027oool00`000?ooooooo`0Koooo00?o003ooooo
ool0eoooo`;o001[oooo000Qoooo00<0003oooooool06_ooo`03o`00oooooooo0=[oool2o`00JOoo
o`008Oooo`80000Joooo00?o003oooooool0gOooo`03o`00oooooooo06Koool0027oool00`000?oo
ooooo`0Hoooo00?o003oooooool0goooo`;o001Voooo000Qoooo00<0003oooooool05oooo`03o`00
oooooooo0>;oool2o`00I?ooo`008Oooo`030000oooooooo01Ooool00ol00?ooooooo`3Toooo0_l0
06;oool0027oool00`000?ooooooo`0Foooo00?o003oooooool0ioooo`03o`00oooooooo05ooool0
027oool200005_ooo`03o`00oooooooo0>Woool2o`00Goooo`008Oooo`030000oooooooo01Coool0
0ol00?ooooooo`3/oooo0_l005goool0027oool00`000?ooooooo`0Doooo00?o003oooooool0k_oo
o`;o001Koooo000Qoooo00<0003oooooool04oooo`03o`00oooooooo0?7oool00ol00?ooooooo`1H
oooo000Qoooo00<0003oooooool04_ooo`03o`00oooooooo0??oool2o`00F?ooo`008Oooo`030000
oooooooo017oool00ol00?ooooooo`3foooo0_l005Koool0027oool200004_ooo`03o`00oooooooo
0?Soool2o`00E?ooo`008Oooo`030000oooooooo013oool00ol00?ooooooo`3koooo0_l005;oool0
027oool00`000?ooooooo`0?oooo00?o003oooooool0o_ooo`;o001@oooo000Qoooo00<0003ooooo
ool03_ooo`03o`00oooooooo0?ooool2oooo0_l004koool000ooool00`000?ooooooo`02oooo00<0
003oooooool00_ooo`030000oooooooo00Goool00`000?ooooooo`0>oooo00?o003oooooool0oooo
o`Coool3o`00Boooo`003_ooo`030000oooo000000Ooool00`000?ooo`000006oooo00<0003ooooo
ool03Oooo`03o`00oooooooo0?ooool8oooo0_l004Woool000koool00`000?ooo`000007oooo00<0
003oool000001_ooo`<0000<oooo00?o003oooooool0ooooo`_oool2o`00Aoooo`003_ooo`030000
oooo000000Soool00`000?ooooooo`05oooo00<0003oooooool02oooo`03o`00oooooooo0?ooool>
oooo0ol004Coool000koool00`000?ooo`000007oooo00<0003oool000001_ooo`030000oooooooo
00_oool00ol00?ooooooo`3ooooo4Oooo`;o0012oooo000?oooo00<0003oooooool01oooo`030000
oooooooo00Goool00`000?ooooooo`0:oooo00?o003oooooool0oooooaCoool2o`00@?ooo`008Ooo
o`030000oooooooo00Woool00ol00?ooooooo`3ooooo5oooo`?o000moooo000Qoooo0P0000[oool0
0ol00?ooooooo`3ooooo6_ooo`;o000koooo000Qoooo00<0003oooooool02?ooo`03o`00oooooooo
0?oooolMoooo0_l003Woool0027oool00`000?ooooooo`07oooo00?o003oooooool0ooooob3oool3
o`00=_ooo`008Oooo`030000oooooooo00Ooool00ol00?ooooooo`3ooooo8oooo`;o000doooo000Q
oooo00<0003oooooool01_ooo`03o`00oooooooo0?oooolVoooo0_l003;oool0027oool00`000?oo
ooooo`05oooo00?o003oooooool0ooooobWoool3o`00;oooo`008Oooo`800006oooo00?o003ooooo
ool0ooooobcoool2o`00;Oooo`008Oooo`030000oooooooo00Coool00ol00?ooooooo`3ooooo;ooo
o`;o000[oooo000Qoooo00<0003oooooool00oooo`03o`00oooooooo0?oooolboooo0ol002Soool0
027oool00`000?ooooooo`02oooo00?o003oooooool0ooooocKoool2o`009_ooo`008Oooo`030000
oooooooo00;oool00ol00?ooooooo`3ooooo>?ooo`;o000Toooo000Qoooo0P0000;oool00ol00?oo
ooooo`3ooooo>oooo`?o000Qoooo000Qoooo00@0003ooooooooo003ooooo@Oooo`;o000Ooooo000Q
oooo00@0003ooooooooo003ooooo@oooo`;o000Moooo000Qoooo00<0003ooooo0000ooooodKoool3
o`006_ooo`005oooo`D00005oooo00<0003o003oool0ooooodWoool2o`006?ooo`006Oooo`030000
oooooooo00Goool00`000?l00?ooo`3oooooBoooo`;o000Foooo000Ioooo00<0003oooooool01Ooo
o`03o`00000000000?oooom=oooo0ol001?oool001Woool00`000?ooooooo`05oooo00<0003ooooo
ool0ooooof?oool001Woool00`000?ooooooo`05oooo00<0003oooooool0ooooof?oool001Soool2
00001oooo`030000oooooooo0?oooomSoooo003oooooQoooo`00\
\>"],
  ImageRangeCache->{{{137.688, 527.063}, {225.563, 95.3125}} -> {-1.52133, 
  0.729029, 0.00890266, 0.00890266}}]
}, Open  ]],

Cell["\t", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "  ",
  StyleBox["Ejemplo  2:",
    FontVariations->{"Underline"->True}],
  " "
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\tCalcular el spline natural asociado a la funci\[OAcute]n ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[ExponentialE]\^x\) \(sen(x)\)\ \)\)]],
  "en el intervalo [-3,3] dividiendo el intervalo en 5 partes iguales."
}], "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\tEmpecemos representando la funci\[OAcute]n a interpolar:", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(f[x_] := \[ExponentialE]\^x\ Sin[x]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f[x], {x, \(-3\), 3}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0390975 0.0756286 [
[.02381 .0266 -6 -9 ]
[.02381 .0266 6 0 ]
[.18254 .0266 -6 -9 ]
[.18254 .0266 6 0 ]
[.34127 .0266 -6 -9 ]
[.34127 .0266 6 0 ]
[.65873 .0266 -3 -9 ]
[.65873 .0266 3 0 ]
[.81746 .0266 -3 -9 ]
[.81746 .0266 3 0 ]
[.97619 .0266 -3 -9 ]
[.97619 .0266 3 0 ]
[.4875 .19035 -6 -4.5 ]
[.4875 .19035 0 4.5 ]
[.4875 .34161 -6 -4.5 ]
[.4875 .34161 0 4.5 ]
[.4875 .49287 -6 -4.5 ]
[.4875 .49287 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .0391 m
.02381 .04535 L
s
[(-3)] .02381 .0266 0 1 Mshowa
.18254 .0391 m
.18254 .04535 L
s
[(-2)] .18254 .0266 0 1 Mshowa
.34127 .0391 m
.34127 .04535 L
s
[(-1)] .34127 .0266 0 1 Mshowa
.65873 .0391 m
.65873 .04535 L
s
[(1)] .65873 .0266 0 1 Mshowa
.81746 .0391 m
.81746 .04535 L
s
[(2)] .81746 .0266 0 1 Mshowa
.97619 .0391 m
.97619 .04535 L
s
[(3)] .97619 .0266 0 1 Mshowa
.125 Mabswid
.05556 .0391 m
.05556 .04285 L
s
.0873 .0391 m
.0873 .04285 L
s
.11905 .0391 m
.11905 .04285 L
s
.15079 .0391 m
.15079 .04285 L
s
.21429 .0391 m
.21429 .04285 L
s
.24603 .0391 m
.24603 .04285 L
s
.27778 .0391 m
.27778 .04285 L
s
.30952 .0391 m
.30952 .04285 L
s
.37302 .0391 m
.37302 .04285 L
s
.40476 .0391 m
.40476 .04285 L
s
.43651 .0391 m
.43651 .04285 L
s
.46825 .0391 m
.46825 .04285 L
s
.53175 .0391 m
.53175 .04285 L
s
.56349 .0391 m
.56349 .04285 L
s
.59524 .0391 m
.59524 .04285 L
s
.62698 .0391 m
.62698 .04285 L
s
.69048 .0391 m
.69048 .04285 L
s
.72222 .0391 m
.72222 .04285 L
s
.75397 .0391 m
.75397 .04285 L
s
.78571 .0391 m
.78571 .04285 L
s
.84921 .0391 m
.84921 .04285 L
s
.88095 .0391 m
.88095 .04285 L
s
.9127 .0391 m
.9127 .04285 L
s
.94444 .0391 m
.94444 .04285 L
s
.25 Mabswid
0 .0391 m
1 .0391 L
s
.5 .19035 m
.50625 .19035 L
s
[(2)] .4875 .19035 1 0 Mshowa
.5 .34161 m
.50625 .34161 L
s
[(4)] .4875 .34161 1 0 Mshowa
.5 .49287 m
.50625 .49287 L
s
[(6)] .4875 .49287 1 0 Mshowa
.125 Mabswid
.5 .07691 m
.50375 .07691 L
s
.5 .11473 m
.50375 .11473 L
s
.5 .15254 m
.50375 .15254 L
s
.5 .22817 m
.50375 .22817 L
s
.5 .26598 m
.50375 .26598 L
s
.5 .3038 m
.50375 .3038 L
s
.5 .37943 m
.50375 .37943 L
s
.5 .41724 m
.50375 .41724 L
s
.5 .45505 m
.50375 .45505 L
s
.5 .00128 m
.50375 .00128 L
s
.5 .53068 m
.50375 .53068 L
s
.5 .5685 m
.50375 .5685 L
s
.5 .60631 m
.50375 .60631 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03857 m
.04262 .03801 L
.06244 .03729 L
.10458 .0353 L
.14264 .03291 L
.18314 .02974 L
.22214 .02617 L
.26358 .0221 L
.30351 .01837 L
.32179 .01692 L
.33219 .01621 L
.34193 .01565 L
.35148 .01521 L
.35685 .01502 L
.36176 .01488 L
.36426 .01483 L
.36692 .01478 L
.36845 .01476 L
.36984 .01474 L
.37123 .01473 L
.37255 .01472 L
.37379 .01472 L
.37511 .01472 L
.37623 .01472 L
.37747 .01472 L
.37816 .01472 L
.3788 .01473 L
.38022 .01474 L
.38154 .01475 L
.38279 .01477 L
.38516 .01481 L
.38738 .01486 L
.39245 .01502 L
.39738 .01523 L
.4027 .01553 L
.41231 .01626 L
.42112 .01716 L
.43093 .01846 L
.44005 .01998 L
.46075 .02464 L
.4812 .03116 L
.49979 .039 L
.51898 .04926 L
.53977 .06319 L
.58069 .1003 L
.6201 .14973 L
.65798 .21075 L
.69832 .28941 L
.73715 .37503 L
.77842 .46877 L
Mistroke
.79906 .51252 L
.81819 .54849 L
.83671 .57677 L
.84706 .58883 L
.85643 .59691 L
.86132 .59991 L
.86378 .60108 L
.86648 .6021 L
.86879 .60273 L
.87008 .60299 L
.87126 .60316 L
.87236 .60326 L
.87355 .60332 L
.87467 .60331 L
.87572 .60326 L
.87691 .60313 L
.8782 .60292 L
.87941 .60265 L
.88052 .60234 L
.88311 .60139 L
.88582 .60003 L
.89095 .59642 L
.89655 .59082 L
.90185 .58383 L
.90685 .57565 L
.9162 .55591 L
.92626 .52763 L
.93716 .48795 L
.95613 .39354 L
.97619 .25346 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/AP00`40o`000?l0003oooooob7oool0
00Woool20000:oooo`<0000Yoooo1@0002Soool20000:Oooo`D0000Yoooo0`0002[oool200002Ooo
o`002oooo`030000oooooooo02Soool00`000?ooooooo`0[oooo00<0003oooooool0:?ooo`030000
oooooooo02[oool00`000?ooooooo`0Yoooo00<0003oooooool0;?ooo`030000oooooooo00Koool0
00Coool300000oooo`030000oooooooo02Coool300000oooo`030000oooooooo02Coool300000ooo
o`030000oooooooo02Soool00`000?ooooooo`0Zoooo00<0003oooooool0:_ooo`030000oooooooo
02[oool00`000?ooooooo`07oooo000;oooo00<0003oooooool0:Oooo`030000oooooooo02[oool0
0`000?ooooooo`0Xoooo00<0003oooooool0:_ooo`030000oooooooo02[oool00`000?ooooooo`0[
oooo00<0003oooooool01_ooo`002Oooo`030000oooo000002[oool00`000?ooo`00000Xoooo5000
01[oool00`000?ooooooo`0Zoooo00<0003oooooool0:Oooo`030000oooo000002[oool00`000?oo
o`000008oooo000:oooo00<0003oooooool0:_ooo`030000oooooooo01Soool?00000_ooo`80000@
oooo200001;oool00`000?ooooooo`0Yoooo0P0002coool00`000?ooooooo`0Zoooo00<0003ooooo
ool01oooo`00Aoooo`/0000[oooo100000koool00`000?ooooooo`2>oooo000koooo300003[oool5
00002Oooo`030000oooooooo08koool0033oool;0000Boooo`<00006oooo00<0003oooooool0S_oo
o`009Oooo`/0001Ioooo0`0000?oool00`000?ooooooo`2>oooo000Joooo2`0006Ooool2000000?o
ool0003oool0Soooo`0000?oool000000000o`0001`00002oooo0008oooo00<0003oooooool01_oo
o`030000oooooooo00Koool00`000?ooooooo`06oooo00<0003oooooool01_ooo`030000oooooooo
00Koool00`000?ooooooo`06oooo00<0003oooooool01_ooo`030000oooooooo00Koool00`000?oo
ooooo`06oooo00<0003oooooool01_ooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0
003oooooool01_ooo`030000oooooooo00Koool00`000?ooooooo`06oooo0`0000Koool00`000?oo
ooooo`06oooo00<0003oooooool01_ooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0
003oooooool01_ooo`030000oooooooo00Koool00`000?ooooooo`06oooo00<0003oooooool01_oo
o`030000oooooooo00Koool00`000?ooooooo`06oooo00<0003oooooool01_ooo`030000oooooooo
00Koool00`000?ooooooo`06oooo00<0003oooooool01_ooo`030000oooooooo00Ooool000Soool0
0`000?ooooooo`0Zoooo00<0003oooooool0:_ooo`030000oooooooo02[oool00`000?ooooooo`02
0000:?ooo`030000oooooooo02[oool00`000?ooooooo`0Zoooo00<0003oooooool01oooo`00Sooo
o`030000oooooooo00;oool00`000?ooooooo`29oooo002?oooo00<0003oooooool00oooo`800029
oooo002?oooo00<0003oooooool01Oooo`030000oooooooo08Koool008ooool00`000?ooooooo`06
oooo0P0008Koool008ooool00`000?ooooooo`08oooo00<0003oooooool0Poooo`00Soooo`030000
oooooooo00Woool00`000?ooooooo`22oooo002?oooo00<0003oooooool02_ooo`030000oooooooo
087oool008ooool00`000?ooooooo`0;oooo0P00087oool008ooool200003_ooo`030000oooooooo
07koool008ooool00`000?ooooooo`0>oooo00<0003oooooool0OOooo`00Soooo`030000oooooooo
00ooool00`000?ooooooo`1loooo002?oooo00<0003oooooool04?ooo`030000oooooooo07_oool0
08ooool00`000?ooooooo`0Aoooo0P0007_oool008ooool00`000?ooooooo`0Coooo00<0003ooooo
ool0N?ooo`00Soooo`030000oooooooo01Coool00`000?ooooooo`1goooo002?oooo00<0003ooooo
ool05Oooo`030000oooooooo07Koool008ooool00`000?ooooooo`0Eoooo00<0003oooooool0M_oo
o`00Soooo`030000oooooooo01Koool00`000?ooooooo`1eoooo002?oooo00<0003oooooool05ooo
o`030000oooooooo07Coool008ooool200006Oooo`030000oooooooo07?oool008ooool00`000?oo
ooooo`0Hoooo00<0003oooooool0Loooo`00Soooo`030000oooooooo01Woool00`000?ooooooo`1b
oooo002?oooo00<0003oooooool06_ooo`030000oooooooo077oool008ooool00`000?ooooooo`0K
oooo00<0003oooooool0L?ooo`00Soooo`030000oooooooo01_oool00`000?ooooooo`1`oooo002?
oooo00<0003oooooool07?ooo`030000oooooooo06ooool008ooool00`000?ooooooo`0Moooo00<0
003oooooool0K_ooo`00Soooo`030000oooooooo01koool00`000?ooooooo`1]oooo002?oooo00<0
003oooooool07_ooo`030000oooooooo06goool008ooool200008?ooo`030000oooooooo06coool0
08ooool00`000?ooooooo`0Poooo00<0003oooooool0Joooo`00Soooo`030000oooooooo023oool0
0`000?ooooooo`1[oooo002?oooo00<0003oooooool08Oooo`030000oooooooo06[oool008ooool0
0`000?ooooooo`0Roooo00<0003oooooool0JOooo`00Soooo`030000oooooooo02;oool00`000?oo
ooooo`1Yoooo002?oooo00<0003oooooool08oooo`030000oooooooo06Soool008ooool00`000?oo
ooooo`0Toooo00<0003oooooool0Ioooo`00Soooo`030000oooooooo02Coool00`000?ooooooo`1W
oooo0027oooo0`0000Goool00`000?ooooooo`0Uoooo00<0003oooooool0I_ooo`00Qoooo`030000
oooooooo00Goool00`000?ooooooo`0Uoooo00<0003oooooool0I_ooo`00R?ooo`030000oooooooo
00Coool300009_ooo`030000oooooooo06Goool008Soool00`000?ooooooo`04oooo00<0003ooooo
ool09oooo`030000oooooooo06Coool008Ooool00`000?ooo`000005oooo00<0003oooooool09ooo
o`030000oooooooo06Coool008Soool00`000?ooooooo`04oooo00<0003oooooool0:?ooo`030000
oooooooo06?oool008ooool00`000?ooooooo`0Yoooo00<0003oooooool0H_ooo`00Soooo`030000
oooooooo02Woool00`000?ooooooo`1Roooo002?oooo00<0003oooooool0:_ooo`030000oooooooo
067oool008ooool00`000?ooooooo`0[oooo00<0003oooooool0H?ooo`00Soooo`030000oooooooo
02_oool00`000?ooooooo`1Poooo002?oooo00<0003oooooool0;?ooo`030000oooooooo05ooool0
08ooool00`000?ooooooo`0/oooo00<0003oooooool0Goooo`00Soooo`80000^oooo00<0003ooooo
ool0G_ooo`00Soooo`030000oooooooo02goool00`000?ooooooo`1Noooo002?oooo00<0003ooooo
ool0;_ooo`030000oooooooo05goool008ooool00`000?ooooooo`0^oooo00<0003oooooool0GOoo
o`00Soooo`030000oooooooo02ooool00`000?ooooooo`1Loooo002?oooo00<0003oooooool0;ooo
o`030000oooooooo05coool008ooool00`000?ooooooo`0`oooo00<0003oooooool0Foooo`00Sooo
o`030000oooooooo033oool00`000?ooooooo`1Aoooo00<0003oooooool01oooo`00Soooo`030000
oooooooo037oool00`000?ooooooo`1@oooo00<0003oooooool01oooo`00Soooo`030000oooooooo
037oool00`000?ooooooo`1@oooo00<0003oooooool01oooo`00Soooo`030000oooooooo03;oool0
0`000?ooooooo`1?oooo00<0003oooooool01oooo`00Soooo`80000coooo00<0003oooooool0C_oo
o`030000oooooooo00Soool008ooool00`000?ooooooo`0coooo00<0003oooooool0COooo`030000
oooooooo00Soool008ooool00`000?ooooooo`0coooo00<0003oooooool0COooo`030000oooooooo
00Soool008ooool00`000?ooooooo`0doooo00<0003oooooool0C?ooo`030000oooooooo00Soool0
08ooool00`000?ooooooo`0doooo00<0003oooooool0C?ooo`030000oooooooo00Soool008ooool0
0`000?ooooooo`0eoooo00<0003oooooool0Boooo`030000oooooooo00Soool008ooool00`000?oo
ooooo`0eoooo00<0003oooooool0Boooo`030000oooooooo00Soool008ooool00`000?ooooooo`0e
oooo00<0003oooooool0Boooo`030000oooooooo00Soool008ooool00`000?ooooooo`0foooo00<0
003oooooool0BOooo`030000oooooooo00Woool008ooool00`000?ooooooo`0foooo00<0003ooooo
ool0BOooo`030000oooooooo00Woool008ooool20000>?ooo`030000oooooooo04Soool00`000?oo
ooooo`09oooo002?oooo00<0003oooooool0=oooo`030000oooooooo04Soool00`000?ooooooo`09
oooo002?oooo00<0003oooooool0>?ooo`030000oooooooo04Ooool00`000?ooooooo`09oooo002?
oooo00<0003oooooool0>?ooo`030000oooooooo04Ooool00`000?ooooooo`09oooo002?oooo00<0
003oooooool0>Oooo`030000oooooooo04Koool00`000?ooooooo`09oooo002?oooo00<0003ooooo
ool0>Oooo`030000oooooooo04Koool00`000?ooooooo`09oooo002?oooo00<0003oooooool0>_oo
o`030000oooooooo04Coool00`000?ooooooo`0:oooo002?oooo00<0003oooooool0>_ooo`030000
oooooooo04Coool00`000?ooooooo`0:oooo002?oooo00<0003oooooool0>oooo`030000oooooooo
04?oool00`000?ooooooo`0:oooo0028oooo0`0000Coool00`000?ooooooo`0koooo00<0003ooooo
ool0@oooo`030000oooooooo00[oool008Woool00`000?ooooooo`03oooo00<0003oooooool0>ooo
o`030000oooooooo04?oool00`000?ooooooo`0:oooo0027oooo100000Coool30000??ooo`030000
oooooooo04;oool00`000?ooooooo`0:oooo0027oooo00<0003oool000001Oooo`030000oooooooo
03coool00`000?ooooooo`12oooo00<0003oooooool02_ooo`00R?ooo`800005oooo00<0003ooooo
ool0?Oooo`030000oooooooo047oool00`000?ooooooo`0:oooo0029oooo00<0003oooooool00ooo
o`030000oooooooo03goool00`000?ooooooo`10oooo00<0003oooooool02oooo`00Soooo`030000
oooooooo03koool00`000?ooooooo`0ooooo00<0003oooooool02oooo`00Soooo`030000oooooooo
03koool00`000?ooooooo`0ooooo00<0003oooooool02oooo`00Soooo`030000oooooooo03ooool0
0`000?ooooooo`0noooo00<0003oooooool02oooo`00Soooo`030000oooooooo03ooool00`000?oo
ooooo`0noooo00<0003oooooool02oooo`00Soooo`030000oooooooo043oool00`000?ooooooo`0m
oooo00<0003oooooool02oooo`00Soooo`030000oooooooo043oool00`000?ooooooo`0moooo00<0
003oooooool02oooo`00Soooo`030000oooooooo043oool00`000?ooooooo`0moooo00<0003ooooo
ool02oooo`00Soooo`800012oooo00<0003oooooool0>oooo`030000oooooooo00coool008ooool0
0`000?ooooooo`11oooo00<0003oooooool0>oooo`030000oooooooo00coool008ooool00`000?oo
ooooo`12oooo00<0003oooooool0>_ooo`030000oooooooo00coool008ooool00`000?ooooooo`12
oooo00<0003oooooool0>_ooo`030000oooooooo00coool008ooool00`000?ooooooo`13oooo00<0
003oooooool0>Oooo`030000oooooooo00coool008ooool00`000?ooooooo`13oooo00<0003ooooo
ool0>Oooo`030000oooooooo00coool008ooool00`000?ooooooo`14oooo00<0003oooooool0>?oo
o`030000oooooooo00coool008ooool00`000?ooooooo`14oooo00<0003oooooool0=oooo`030000
oooooooo00goool008ooool00`000?ooooooo`14oooo00<0003oooooool0=oooo`030000oooooooo
00goool008ooool00`000?ooooooo`15oooo00<0003oooooool0=_ooo`030000oooooooo00goool0
08ooool20000A_ooo`030000oooooooo03Koool00`000?ooooooo`0=oooo002?oooo00<0003ooooo
ool0A_ooo`030000oooooooo03Coool00`000?ooooooo`0>oooo002?oooo00<0003oooooool0A_oo
o`030000oooooooo03Coool00`000?ooooooo`0>oooo002?oooo00<0003oooooool0Aoooo`030000
oooooooo03?oool00`000?ooooooo`0>oooo002?oooo00<0003oooooool0Aoooo`030000oooooooo
03?oool00`000?ooooooo`0>oooo002?oooo00<0003oooooool0B?ooo`030000oooooooo03;oool0
0`000?ooooooo`0>oooo002?oooo00<0003oooooool0B?ooo`030000oooooooo037oool00`000?oo
ooooo`0?oooo002?oooo00<0003oooooool0B?ooo`030000oooooooo037oool00`000?ooooooo`0?
oooo002?oooo00<0003oooooool0BOooo`030000oooooooo033oool00`000?ooooooo`0?oooo002?
oooo00<0003oooooool0BOooo`030000oooooooo033oool00`000?ooooooo`0?oooo002?oooo00<0
003oooooool0B_ooo`030000oooooooo02koool00`000?ooooooo`0@oooo002?oooo0P0004_oool0
0`000?ooooooo`0^oooo00<0003oooooool04?ooo`00Soooo`030000oooooooo04_oool00`000?oo
ooooo`0]oooo00<0003oooooool04?ooo`00Soooo`030000oooooooo04_oool00`000?ooooooo`0]
oooo00<0003oooooool04?ooo`00Soooo`030000oooooooo04coool00`000?ooooooo`0/oooo00<0
003oooooool04?ooo`00Soooo`030000oooooooo04coool00`000?ooooooo`0[oooo00<0003ooooo
ool04Oooo`00Soooo`030000oooooooo04coool00`000?ooooooo`0[oooo00<0003oooooool04Ooo
o`00Soooo`030000oooooooo04goool00`000?ooooooo`0Zoooo00<0003oooooool04Oooo`00Sooo
o`030000oooooooo04goool00`000?ooooooo`0Zoooo00<0003oooooool04Oooo`00Soooo`030000
oooooooo04koool00`000?ooooooo`0Xoooo00<0003oooooool04_ooo`00Qoooo`800006oooo00<0
003oooooool0C_ooo`030000oooooooo02Soool00`000?ooooooo`0Boooo0027oooo00<0003oool0
00001Oooo`030000oooooooo04ooool00`000?ooooooo`0Woooo00<0003oooooool04_ooo`00Qooo
o`030000oooo000000Goool30000Coooo`030000oooooooo02Ooool00`000?ooooooo`0Boooo0027
oooo0P0000Koool00`000?ooooooo`1@oooo00<0003oooooool09Oooo`030000oooooooo01?oool0
08Ooool00`000?ooooooo`05oooo00<0003oooooool0D?ooo`030000oooooooo02Goool00`000?oo
ooooo`0Coooo0028oooo0P0000Goool00`000?ooooooo`1Aoooo00<0003oooooool09?ooo`030000
oooooooo01?oool008ooool00`000?ooooooo`1Aoooo00<0003oooooool09?ooo`030000oooooooo
01?oool008ooool00`000?ooooooo`1Boooo00<0003oooooool08_ooo`030000oooooooo01Coool0
08ooool00`000?ooooooo`1Boooo00<0003oooooool08_ooo`030000oooooooo01Coool008ooool0
0`000?ooooooo`1Coooo00<0003oooooool08Oooo`030000oooooooo01Coool008ooool00`000?oo
ooooo`1Coooo00<0003oooooool08Oooo`030000oooooooo01Coool008ooool00`000?ooooooo`1D
oooo00<0003oooooool07oooo`030000oooooooo01Goool008ooool00`000?ooooooo`1Doooo00<0
003oooooool07oooo`030000oooooooo01Goool008ooool20000E_ooo`030000oooooooo01koool0
0`000?ooooooo`0Eoooo002?oooo00<0003oooooool0EOooo`030000oooooooo01goool00`000?oo
ooooo`0Foooo002?oooo00<0003oooooool0E_ooo`030000oooooooo01coool00`000?ooooooo`0F
oooo002?oooo00<0003oooooool0E_ooo`030000oooooooo01_oool00`000?ooooooo`0Goooo002?
oooo00<0003oooooool0Eoooo`030000oooooooo01[oool00`000?ooooooo`0Goooo002?oooo00<0
003oooooool0Eoooo`030000oooooooo01[oool00`000?ooooooo`0Goooo002?oooo00<0003ooooo
ool0F?ooo`030000oooooooo01Soool00`000?ooooooo`0Hoooo002?oooo00<0003oooooool0FOoo
o`030000oooooooo01Ooool00`000?ooooooo`0Hoooo002?oooo00<0003oooooool0FOooo`030000
oooooooo01Ooool00`000?ooooooo`0Hoooo002?oooo00<0003oooooool0F_ooo`030000oooooooo
01Goool00`000?ooooooo`0Ioooo002?oooo0P0005coool00`000?ooooooo`0Doooo00<0003ooooo
ool06Oooo`00Soooo`030000oooooooo05coool00`000?ooooooo`0Boooo00<0003oooooool06_oo
o`00Soooo`030000oooooooo05coool00`000?ooooooo`0Boooo00<0003oooooool06_ooo`00Sooo
o`030000oooooooo05goool00`000?ooooooo`0@oooo00<0003oooooool06oooo`00Soooo`030000
oooooooo05koool00`000?ooooooo`0?oooo00<0003oooooool06oooo`00Soooo`030000oooooooo
05ooool00`000?ooooooo`0=oooo00<0003oooooool07?ooo`00Soooo`030000oooooooo063oool0
0`000?ooooooo`0;oooo00<0003oooooool07Oooo`00Soooo`030000oooooooo067oool00`000?oo
ooooo`0:oooo00<0003oooooool07Oooo`00Soooo`030000oooooooo067oool00`000?ooooooo`08
oooo0P00023oool008ooool00`000?ooooooo`1Roooo0`0000Koool00`000?ooooooo`0Poooo002?
oooo00<0003oooooool0I?ooo`L0000Soooo002?oooo0P0008ooool008ooool00`000?ooooooo`2>
oooo002?oooo00<0003oooooool0S_ooo`00Soooo`030000oooooooo08koool00001\
\>"],
  ImageRangeCache->{{{137.688, 424.688}, {574.75, 397.813}} -> {-6.23874, 
  17.9404, 0.0221871, 0.0465665}}]
}, Open  ]],

Cell["\<\
\tLa longitud de paso es h=6/5=1.2. Por tanto la tabla de valores sobre la \
que hemos de calcular el spline natural es:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(lista = Table[{\(-3.\) + 1.2*i, f[\(-3.\) + 1.2*i]}, {i, 0, 5}]\)], 
  "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", 
              StyleBox["3.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", \(-0.00702595148935011959`\)}], 
          "}"}], ",", \({\(-1.8`\), \(-0.160975930681391616`\)}\), ",", 
        \({\(-0.600000000000000088`\), \(-0.309882359632107196`\)}\), ",", 
        \({0.599999999999999644`, 1.02884566627209061`}\), ",", 
        \({1.79999999999999982`, 5.89143485086682705`}\), ",", 
        \({3.`, 2.83447113248700421`}\)}], "}"}]], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell["\tLa lista de abscisas y de ordenadas es:", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(listax = \(Drop[Transpose[lista], \(-1\)]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"-", 
          StyleBox["3.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(-1.8`\), ",", 
        \(-0.600000000000000088`\), ",", "0.599999999999999644`", ",", 
        "1.79999999999999982`", ",", "3.`"}], "}"}]], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(listay = \(Drop[Transpose[lista], 1]\)[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({\(-0.00702595148935011959`\), \(-0.160975930681391616`\), 
      \(-0.309882359632107196`\), 1.02884566627209061`, 5.89143485086682705`, 
      2.83447113248700421`}\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(p1 = Espline[listax, listay, x]\)], "Input"],

Cell[BoxData[
    \({\(-0.00702595148935011959`\) - 
        0.128223545373061931`\ \((\(3.`\[InvisibleSpace]\) + x)\) - 
        0.0000472944122495233454`\ \((\(3.`\[InvisibleSpace]\) + x)\)\^3, 
      \(-0.160975930681391616`\) - 
        0.128427857233979892`\ \((\(1.8`\[InvisibleSpace]\) + x)\) - 
        0.000170259884098284031`\ \((\(1.8`\[InvisibleSpace]\) + x)\)\^2 + 
        0.00315519326571864988`\ \((\(1.8`\[InvisibleSpace]\) + x)\)\^3, 
      \(-0.309882359632107196`\) - 
        0.115206046047911181`\ 
          \((\(0.600000000000000088`\[InvisibleSpace]\) + x)\) + 
        0.0111884358724888555`\ 
          \((\(0.600000000000000088`\[InvisibleSpace]\) + x)\)\^2 + 
        0.845407368926682956`\ 
          \((\(0.600000000000000088`\[InvisibleSpace]\) + x)\)\^3, 
      \(1.02884566627209061`\[InvisibleSpace]\) + 
        3.56380603380933003`\ \((\(-0.599999999999999644`\) + x)\) + 
        3.05465496400854652`\ \((\(-0.599999999999999644`\) + x)\)\^2 - 
        2.20641273388238801`\ \((\(-0.599999999999999644`\) + x)\)\^3, 
      \(5.89143485086682705`\[InvisibleSpace]\) + 
        1.36327493705792335`\ \((\(-1.79999999999999982`\) + x)\) - 
        4.88843087796805164`\ \((\(-1.79999999999999982`\) + x)\)\^2 + 
        1.35789746610223627`\ \((\(-1.79999999999999982`\) + x)\)\^3}\)], 
  "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell["\<\
\tCalculamos el spline natural siguiendo el mismo esquema que hemos utilizado \
antes:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(Clear[pol1, pol2, pol3, s1, s2, s3, S]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol1 = Expand[p1[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-0.392973536739273079`\) - 0.129500494503799078`\ x - 
      0.0004256497102457101`\ x\^2 - 0.0000472944122495233454`\ x\^3\)], 
  "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol2 = Expand[p1[\([2]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-0.374296628601362701`\) - 0.0983723142739484401`\ x + 
      0.0168677837507824275`\ x\^2 + 0.00315519326571864988`\ x\^3\)], 
  "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol3 = Expand[p1[\([3]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-0.192370158658594334`\) + 0.811260035439893201`\ x + 
      1.53292169994051841`\ x\^2 + 0.845407368926682956`\ x\^3\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol4 = Expand[p1[\([4]\)]]\)], "Input"],

Cell[BoxData[
    \(\(0.466822983548164494`\[InvisibleSpace]\) - 2.48470567559389987`\ x + 
      7.02619788499684272`\ x\^2 - 2.20641273388238801`\ x\^3\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pol5 = Expand[p1[\([5]\)]]\)], "Input"],

Cell[BoxData[
    \(\(-20.320234102762158`\) + 32.1603894682566382`\ x - 
      12.2210771949201268`\ x\^2 + 1.35789746610223627`\ x\^3\)], "Output",
  CellFrame->True,
  Background->GrayLevel[1]]
}, Open  ]],

Cell[BoxData[
    \(\(s1[t_] := pol1 /. x -> t; \ns2[t_] := pol2 /. x -> t; \n
    s3[t_] := pol3 /. x -> t; \ns4[t_] := pol4 /. x -> t; \n
    s5[t_] := pol5 /. x -> t; \n\)\)], "Input"],

Cell["\tEstamos ya en condiciones de definir el spline natural:", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[BoxData[
    \(S[x_] := s1[x] /; \(-3\) \[LessEqual] x \[LessEqual] listax[\([2]\)]; \n
    S[x_] := s2[x] /; 
        listax[\([2]\)] \[LessEqual] x \[LessEqual] listax[\([3]\)]; \n
    S[x_] := s3[x] /; 
        listax[\([3]\)] \[LessEqual] x \[LessEqual] listax[\([4]\)]; \n
    S[x_] := s4[x] /; 
        listax[\([4]\)] \[LessEqual] x \[LessEqual] listax[\([5]\)]; \n
    S[x_] := s5[x] /; 
        listax[\([5]\)] \[LessEqual] x \[LessEqual] listax[\([6]\)]; \)], 
  "Input"],

Cell["\<\
\tLa representaci\[OAcute]n gr\[AAcute]fica conjunta de la funci\[OAcute]n \
interpoladora y de la funci\[OAcute]n inicial muestra que las aproximaciones \
pueden no ser buenas en algunas zonas del intervalo por el escaso \
n\[UAcute]mero de puntos seleccionado:\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{f[x], S[x]}, {x, \(-3\), 3}, 
      PlotStyle -> {RGBColor[1, 0, 0], RGBColor[0, 1, 0]}, 
      AspectRatio -> Automatic]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2977 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0826043 0.15873 [
[.02381 .0701 -6 -9 ]
[.02381 .0701 6 0 ]
[.18254 .0701 -6 -9 ]
[.18254 .0701 6 0 ]
[.34127 .0701 -6 -9 ]
[.34127 .0701 6 0 ]
[.65873 .0701 -3 -9 ]
[.65873 .0701 3 0 ]
[.81746 .0701 -3 -9 ]
[.81746 .0701 3 0 ]
[.97619 .0701 -3 -9 ]
[.97619 .0701 3 0 ]
[.4875 .40006 -6 -4.5 ]
[.4875 .40006 0 4.5 ]
[.4875 .71753 -6 -4.5 ]
[.4875 .71753 0 4.5 ]
[.4875 1.03499 -6 -4.5 ]
[.4875 1.03499 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.2977 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .0826 m
.02381 .08885 L
s
[(-3)] .02381 .0701 0 1 Mshowa
.18254 .0826 m
.18254 .08885 L
s
[(-2)] .18254 .0701 0 1 Mshowa
.34127 .0826 m
.34127 .08885 L
s
[(-1)] .34127 .0701 0 1 Mshowa
.65873 .0826 m
.65873 .08885 L
s
[(1)] .65873 .0701 0 1 Mshowa
.81746 .0826 m
.81746 .08885 L
s
[(2)] .81746 .0701 0 1 Mshowa
.97619 .0826 m
.97619 .08885 L
s
[(3)] .97619 .0701 0 1 Mshowa
.125 Mabswid
.05556 .0826 m
.05556 .08635 L
s
.0873 .0826 m
.0873 .08635 L
s
.11905 .0826 m
.11905 .08635 L
s
.15079 .0826 m
.15079 .08635 L
s
.21429 .0826 m
.21429 .08635 L
s
.24603 .0826 m
.24603 .08635 L
s
.27778 .0826 m
.27778 .08635 L
s
.30952 .0826 m
.30952 .08635 L
s
.37302 .0826 m
.37302 .08635 L
s
.40476 .0826 m
.40476 .08635 L
s
.43651 .0826 m
.43651 .08635 L
s
.46825 .0826 m
.46825 .08635 L
s
.53175 .0826 m
.53175 .08635 L
s
.56349 .0826 m
.56349 .08635 L
s
.59524 .0826 m
.59524 .08635 L
s
.62698 .0826 m
.62698 .08635 L
s
.69048 .0826 m
.69048 .08635 L
s
.72222 .0826 m
.72222 .08635 L
s
.75397 .0826 m
.75397 .08635 L
s
.78571 .0826 m
.78571 .08635 L
s
.84921 .0826 m
.84921 .08635 L
s
.88095 .0826 m
.88095 .08635 L
s
.9127 .0826 m
.9127 .08635 L
s
.94444 .0826 m
.94444 .08635 L
s
.25 Mabswid
0 .0826 m
1 .0826 L
s
.5 .40006 m
.50625 .40006 L
s
[(2)] .4875 .40006 1 0 Mshowa
.5 .71753 m
.50625 .71753 L
s
[(4)] .4875 .71753 1 0 Mshowa
.5 1.03499 m
.50625 1.03499 L
s
[(6)] .4875 1.03499 1 0 Mshowa
.125 Mabswid
.5 .16197 m
.50375 .16197 L
s
.5 .24133 m
.50375 .24133 L
s
.5 .3207 m
.50375 .3207 L
s
.5 .47943 m
.50375 .47943 L
s
.5 .55879 m
.50375 .55879 L
s
.5 .63816 m
.50375 .63816 L
s
.5 .79689 m
.50375 .79689 L
s
.5 .87626 m
.50375 .87626 L
s
.5 .95562 m
.50375 .95562 L
s
.5 .00324 m
.50375 .00324 L
s
.5 1.11435 m
.50375 1.11435 L
s
.5 1.19372 m
.50375 1.19372 L
s
.5 1.27308 m
.50375 1.27308 L
s
.25 Mabswid
.5 0 m
.5 1.2977 L
s
0 0 m
1 0 L
1 1.2977 L
0 1.2977 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .08149 m
.04262 .08032 L
.06244 .07882 L
.10458 .07464 L
.14264 .06962 L
.18314 .06296 L
.22214 .05548 L
.26358 .04693 L
.30351 .0391 L
.32179 .03605 L
.33219 .03457 L
.34193 .0334 L
.35148 .03247 L
.35685 .03207 L
.36176 .03178 L
.36426 .03167 L
.36692 .03157 L
.36845 .03152 L
.36984 .03149 L
.37123 .03146 L
.37255 .03145 L
.37379 .03143 L
.37511 .03143 L
.37623 .03143 L
.37747 .03144 L
.37816 .03145 L
.3788 .03145 L
.38022 .03148 L
.38154 .03151 L
.38279 .03155 L
.38516 .03163 L
.38738 .03174 L
.39245 .03207 L
.39738 .03251 L
.4027 .03313 L
.41231 .03466 L
.42112 .03657 L
.43093 .0393 L
.44005 .04248 L
.46075 .05226 L
.4812 .06595 L
.49979 .0824 L
.51898 .10394 L
.53977 .13317 L
.58069 .21106 L
.6201 .31481 L
.65798 .44288 L
.69832 .60797 L
.73715 .78767 L
.77842 .9844 L
Mistroke
.79906 1.07624 L
.81819 1.15172 L
.83671 1.21109 L
.84706 1.23639 L
.85643 1.25334 L
.86132 1.25965 L
.86378 1.26211 L
.86648 1.26423 L
.86879 1.26556 L
.87008 1.2661 L
.87126 1.26646 L
.87236 1.26668 L
.87355 1.2668 L
.87467 1.26679 L
.87572 1.26667 L
.87691 1.26641 L
.8782 1.26597 L
.87941 1.2654 L
.88052 1.26475 L
.88311 1.26276 L
.88582 1.2599 L
.89095 1.25232 L
.89655 1.24057 L
.90185 1.2259 L
.90685 1.20873 L
.9162 1.1673 L
.92626 1.10793 L
.93716 1.02466 L
.95613 .82651 L
.97619 .53252 L
Mfstroke
0 1 0 r
.02381 .08149 m
.06244 .07654 L
.10458 .07113 L
.14415 .06606 L
.18221 .06117 L
.22272 .05597 L
.26171 .05097 L
.30316 .04572 L
.34309 .04076 L
.3815 .03613 L
.40095 .03386 L
.41127 .03268 L
.41696 .03208 L
.42237 .03159 L
.42744 .03123 L
.43031 .03108 L
.43168 .03102 L
.43298 .03098 L
.43416 .03094 L
.43544 .03092 L
.4366 .0309 L
.43767 .0309 L
.43884 .0309 L
.44011 .03091 L
.44075 .03093 L
.44144 .03094 L
.44268 .03098 L
.44395 .03103 L
.44513 .03109 L
.4478 .03126 L
.45014 .03147 L
.45264 .03174 L
.45695 .03237 L
.46172 .03328 L
.46663 .03451 L
.47181 .03612 L
.48106 .03994 L
.49102 .04554 L
.50192 .05366 L
.52153 .07435 L
.53251 .0898 L
.54248 .10653 L
.56167 .14669 L
.58246 .20345 L
.62338 .3595 L
.66278 .54745 L
.70067 .73295 L
.72175 .82747 L
.74101 .90309 L
.76093 .96638 L
Mistroke
.77085 .99097 L
.77984 1.00869 L
.78446 1.01599 L
.78945 1.02242 L
.7922 1.02531 L
.79472 1.02757 L
.79729 1.02949 L
.79968 1.03093 L
.80174 1.03191 L
.80395 1.0327 L
.80521 1.03302 L
.8064 1.03325 L
.80747 1.03339 L
.80863 1.03347 L
.80977 1.03348 L
.81102 1.0334 L
.81232 1.03324 L
.81354 1.033 L
.81468 1.03271 L
.81573 1.03238 L
.81808 1.03144 L
.82057 1.03013 L
.82284 1.02868 L
.82791 1.02449 L
.83704 1.01388 L
.8477 .99675 L
.85776 .97628 L
.89628 .86486 L
.93725 .7047 L
.97619 .53252 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{221.875, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181P00`40o`000?l0003ogOooo`00K_oo
o`030000oooooooo06coool006koool20000KOooo`00K_ooo`030000oooooooo06coool006koool0
0`000?ooooooo`1/oooo001^oooo00<0003oooooool0K?ooo`00K_ooo`030000oooooooo06coool0
06koool00`000?ooooooo`1/oooo001=oooo3Ol000`0o`08oooo00<0003oooooool0K?ooo`001ooo
o`80000Poooo0`0001Woool8o`000`0000X0o`000oooool00?l00002o`001oooo`@0o`04oooo00<0
003oooooool07_ooo`D0000Ooooo0`00023oool200001Oooo`002Oooo`030000oooooooo01goool0
0`000?ooooooo`0Eoooo1?l000?oool80?l03oooo`;o0009oooo0P3o00;oool00`000?ooooooo`0P
oooo00<0003oooooool07oooo`030000oooooooo02;oool00`000?ooooooo`02oooo0002oooo0`00
00?oool00`000?ooooooo`0Ioooo0`0000?oool00`000?ooooooo`0@oooo0_l000T0o`0200000ooo
o`030000oooooooo017oool2o`002Oooo`030?l0oooo000002;oool00`000?ooooooo`0Poooo00<0
003oooooool08?ooo`030000oooooooo00?oool000Woool00`000?ooooooo`0Noooo00<0003ooooo
ool02Oooo`T0o`0>oooo00<0003oooooool04oooo`;o0008oooo0P3o02;oool00`000?ooooooo`0P
oooo00<0003oooooool08Oooo`030000oooooooo00;oool000Ooool00`000?ooo`00000Ooooo00<0
003oool000000oooo`L0o`0Goooo00<0003oooooool05Oooo`;o0007oooo00<00000o`3oool08?oo
o`030000oooooooo01ooool00`000?ooo`00000Poooo00<0003oool000001?ooo`002?ooo`030000
oooooooo01ooool00`00003o003o00020?l07Oooo`80000Ioooo0_l000Goool00`000?ooo`3o000O
oooo0P0002;oool00`000?ooooooo`0Poooo00<0003oooooool00oooo`009?ooo`L0o`0noooo00?o
003oooooool00_ooo`040000oooooooo0?l0Joooo`007?ooo`P0o`03o`00@oooo`05o`00oooooooo
oooo000000;oool00`3o0?ooooooo`1Yoooo000Coooo2@3o00Oo0018oooo0_l00003oooo0000oooo
00;oool00`3o0?ooooooo`1Xoooo000:oooo2@3o00Wo001Aoooo00?o0000003oool00oooo`030?l0
oooooooo06Ooool000H000040?l02Ol005/000000ol0000000000003000000<0o`0000000000IP00
00001_ooo`030000oooooooo00?oool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000
oooooooo00Coool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool0
0`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04
oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003ooooo
ool01?ooo`030000o`00oooo00?oool00`3o00000?ooo`05oooo00<0003oooooool01?ooo`030000
oooooooo00Coool00`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool0
0`000?ooooooo`04oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04
oooo00<0003oooooool01?ooo`030000oooooooo00Coool00`000?ooooooo`04oooo00<0003ooooo
ool01?ooo`030000oooooooo00?oool000Koool00`000?ooooooo`0Ooooo00<0003oooooool08?oo
o`030000oooooooo023oool00`000?ooool00004oooo00<0o`3oooooool06Oooo`030000oooooooo
023oool00`000?ooooooo`0Poooo00<0003oooooool00oooo`00K_ooo`030000ooooo`0000Goool0
0`3o0?ooooooo`1Toooo001^oooo00@0003ooooooooo0005oooo00<0o`3oooooool0Hoooo`00K_oo
o`050000ooooooooooooo`0000Coool00`3o0?ooooooo`1Soooo001^oooo00<0003oooooool00_oo
o`03o`00oooooooo00;oool00`3o0?ooooooo`1Roooo001^oooo00<0003oooooool00oooo`03o`00
oooooooo00;oool00`3o0?ooooooo`1Qoooo001^oooo00<0003oooooool00oooo`03o`00oooooooo
00;oool00`3o0?ooooooo`1Qoooo001^oooo00<0003oooooool01?ooo`03o`00oooooooo00;oool0
0`3o0?ooooooo`1Poooo001^oooo00<0003oooooool01Oooo`05o`00oooooooooooo0?l006;oool0
06koool00`000?ooooooo`06oooo00Go003oooooooooool0o`00HOooo`00K_ooo`030000oooooooo
00Ooool01?l00?ooooooo`3o067oool006koool00`000?ooooooo`07oooo00Go003oooooooooool0
o`00H?ooo`00K_ooo`030000oooooooo00Soool01?l00?ooooooo`3o063oool006koool00`000?oo
ooooo`08oooo00Co003oooooool0o`1Poooo001^oooo00<0003oooooool02Oooo`04o`00oooooooo
0?l0Goooo`00K_ooo`030000oooooooo00Woool01?l00?ooooooo`3o05ooool006koool200002ooo
o`03o`00oooo0?l005ooool006koool00`000?ooooooo`0:oooo00Co003oooooool0o`1Noooo001^
oooo00<0003oooooool02oooo`03o`00oooo0?l005koool006koool00`000?ooooooo`0;oooo00?o
003oool0o`00G_ooo`00K_ooo`030000oooooooo00coool00ol0003o0?ooo`1Moooo001^oooo00<0
003oooooool03?ooo`03o`00oooo0?l005goool006koool00`000?ooooooo`0=oooo00?o0000o`3o
ool0G?ooo`00K_ooo`030000oooooooo00goool00ol0003o0?ooo`1Loooo001^oooo00<0003ooooo
ool03_ooo`03o`000?l0oooo05_oool006koool00`000?ooooooo`0>oooo00?o0000o`3oool0Fooo
o`00K_ooo`030000oooooooo00ooool00`3o0?ooooooo`1Joooo001^oooo00<0003oooooool03ooo
o`03o`000?l0oooo05[oool006koool00`000?ooooooo`0?oooo00?o0000o`3oool0F_ooo`00K_oo
o`030000oooooooo013oool00`3o0?ooooooo`1Ioooo001^oooo00<0003oooooool04?ooo`030?l0
oooooooo05Woool006koool00`000?ooooooo`0Aoooo00<0o`3oooooool0F?ooo`00K_ooo`030000
oooooooo017oool00`3o0?ooooooo`1Hoooo001^oooo0P0001;oool00`3o0?ooooooo`1Hoooo001^
oooo00<0003oooooool04Oooo`030?l0o`00oooo05Soool006koool00`000?ooooooo`0Boooo00<0
o`3oooooool0Eoooo`00K_ooo`030000oooooooo01;oool00`3o0?l00?ooo`1Goooo001^oooo00<0
003oooooool04_ooo`030?l0o`00oooo05Ooool006koool00`000?ooooooo`0Boooo00<0o`3o003o
ool0Eoooo`00K_ooo`030000oooooooo01?oool00`3o0?l00?ooo`1Foooo001^oooo00<0003ooooo
ool04oooo`030?l0o`00oooo05Koool006koool00`000?ooooooo`0Coooo00<0o`3ooooo0000E_oo
o`00K_ooo`030000oooooooo01?oool00`3o0?ooool0001Foooo001^oooo00<0003oooooool05?oo
o`030?l0ooooo`0005Goool006koool00`000?ooooooo`0Doooo00<0o`3ooooo0000EOooo`00K_oo
o`030000oooooooo01Coool00`3o0?ooool0001Eoooo001^oooo00<0003oooooool05Oooo`030?l0
ooooo`0005Coool006koool00`000?ooooooo`0Eoooo00<0o`3ooooo0000E?ooo`00K_ooo`030000
oooooooo01Goool0103o0?ooooooool005?oool006koool00`000?ooooooo`0Eoooo00@0o`3ooooo
oooo001Coooo001^oooo00<0003oooooool05_ooo`030?l0ooooo`0005?oool006koool200005ooo
o`040?l0ooooooooo`00D_ooo`00K_ooo`030000oooooooo01Koool0103o0?ooooooool005;oool0
06koool00`000?ooooooo`0Foooo00@0o`3ooooooooo001Boooo001^oooo00<0003oooooool05ooo
o`030?l0ooooo`0005;oool006koool00`000?ooooooo`0Goooo00@0o`3ooooooooo001Aoooo001^
oooo00<0003oooooool05oooo`040?l0ooooooooo`00DOooo`00K_ooo`030000oooooooo01Ooool0
103o0?ooooooool0057oool006koool00`000?ooooooo`0Hoooo00<0o`3ooooo0000DOooo`00K_oo
o`030000oooooooo01Soool0103o0?ooooooool0053oool006koool00`000?ooooooo`0Hoooo00@0
o`3ooooooooo001@oooo001^oooo00<0003oooooool06?ooo`040?l0ooooooooo`00D?ooo`00K_oo
o`030000oooooooo01Woool0103o0?ooooooool004ooool006koool00`000?ooooooo`0Ioooo00@0
o`3ooooooooo001?oooo001^oooo00<0003oooooool06Oooo`040?l0ooooooooo`00Coooo`00K_oo
o`030000oooooooo01Woool0103o0?ooooooool004ooool006Soool300000oooo`030000oooooooo
01Woool01@3o0?ooooooooooool0001>oooo001Xoooo00<0003oooooool00oooo`030000oooooooo
01[oool0103o0?ooooooool004koool006Woool00`000?ooooooo`02oooo0`0001[oool0103o0?oo
ooooool004koool006Woool00`000?ooooooo`02oooo00<0003oooooool06_ooo`050?l0oooooooo
ooooo`0004goool006Soool00`000?ooo`000003oooo00<0003oooooool06_ooo`050?l0oooooooo
ooooo`0004goool006Woool00`000?ooooooo`02oooo00<0003oooooool06oooo`040?l0oooooooo
o`00COooo`00K_ooo`030000oooooooo01_oool0103o0?ooooooool004goool006koool00`000?oo
ooooo`0Koooo00D0o`3ooooooooooooo0000C?ooo`00K_ooo`030000oooooooo01_oool01@3o0?oo
ooooooooool0001<oooo001^oooo00<0003oooooool06oooo`050?l0ooooooooooooo`0004coool0
06koool00`000?ooooooo`0Loooo00@0o`3ooooooooo001<oooo001^oooo00<0003oooooool07?oo
o`050?l0ooooooooooooo`0004_oool006koool00`000?ooooooo`0Loooo00D0o`3ooooooooooooo
0000Boooo`00K_ooo`030000oooooooo01coool01@3o0?ooooooooooool0001;oooo001^oooo00<0
003oooooool07?ooo`030?l0oooooooo00;oool00ol00?ooooooo`18oooo001^oooo00<0003ooooo
ool07Oooo`050?l0ooooooooooooo`0004[oool006koool00`000?ooooooo`0Moooo00D0o`3ooooo
oooooooo0000B_ooo`00K_ooo`030000oooooooo01goool01@3o0?ooooooooooool0001:oooo001^
oooo00<0003oooooool07Oooo`030?l0oooooooo00;oool00ol00?ooooooo`17oooo001^oooo00<0
003oooooool07_ooo`050?l0ooooooooooooo`0004Woool006koool200007oooo`050?l0oooooooo
ooooo`0004Woool006koool00`000?ooooooo`0Noooo00D0o`3ooooooooooooo0000BOooo`00K_oo
o`030000oooooooo01koool00`3o0?ooooooo`02oooo00?o003oooooool0A_ooo`00K_ooo`030000
oooooooo01koool00`3o0?ooooooo`02oooo00?o003oooooool0A_ooo`00K_ooo`030000oooooooo
01ooool01@3o0?ooooooooooool00018oooo001^oooo00<0003oooooool07oooo`050?l0oooooooo
ooooo`0004Soool006koool00`000?ooooooo`0Ooooo00<0o`3oooooool00_ooo`03o`00oooooooo
04Goool006koool00`000?ooooooo`0Ooooo00<0o`3oooooool00_ooo`03o`00oooooooo04Goool0
06koool00`000?ooooooo`0Ooooo00<0o`3oooooool00_ooo`03o`00oooooooo04Goool006koool0
0`000?ooooooo`0Poooo00D0o`3ooooooooooooo0000Aoooo`00K_ooo`030000oooooooo023oool0
0`3o0?ooooooo`02oooo00?o003oooooool0A?ooo`00K_ooo`030000oooooooo023oool00`3o0?oo
ooooo`02oooo00?o003oooooool0?_ooo`030?l0oooooooo00?oool006koool00`000?ooooooo`0P
oooo00<0o`3oooooool00_ooo`03o`00oooooooo03koool00`3o0?ooooooo`03oooo001^oooo00<0
003oooooool08Oooo`050?l0ooooooooooooo`00043oool00`3o0?ooooooo`03oooo001^oooo00<0
003oooooool08Oooo`030?l0oooooooo00;oool00ol00?ooooooo`0loooo00<0o`3o003oool01?oo
o`00K_ooo`030000oooooooo027oool00`3o0?ooooooo`02oooo00?o003oooooool0??ooo`030?l0
o`00oooo00Coool006koool00`000?ooooooo`0Qoooo00<0o`3oooooool00_ooo`03o`00oooooooo
03coool00`3o0?l00?ooo`04oooo001^oooo0P0002;oool00`3o0?ooooooo`02oooo00?o003ooooo
ool0??ooo`030?l0o`00oooo00Coool006koool00`000?ooooooo`0Roooo00<0o`3oooooool00_oo
o`03o`00oooooooo03_oool00`3o0?l00?ooo`04oooo001^oooo00<0003oooooool08_ooo`030?l0
oooooooo00;oool00ol00?ooooooo`0joooo00<0o`3ooooo00001Oooo`00K_ooo`030000oooooooo
02;oool00`3o0?ooooooo`02oooo00?o003oooooool0>_ooo`030?l0o`00oooo00Goool006koool0
0`000?ooooooo`0Roooo00<0o`3oooooool00_ooo`03o`00oooooooo03[oool00`3o0?l00?ooo`05
oooo001^oooo00<0003oooooool08_ooo`030?l0oooooooo00?oool00ol00?ooooooo`0ioooo00<0
o`3o003oool01Oooo`00K_ooo`030000oooooooo02?oool00`3o0?ooooooo`02oooo00?o003ooooo
ool0>?ooo`030?l0ooooo`0000Koool006koool00`000?ooooooo`0Soooo00<0o`3oooooool00_oo
o`03o`00oooooooo03Soool00`3o0?ooool00006oooo001^oooo00<0003oooooool08oooo`030?l0
oooooooo00;oool00ol00?ooooooo`0hoooo00<0o`3ooooo00001_ooo`00K_ooo`030000oooooooo
02?oool00`3o0?ooooooo`03oooo00?o003oooooool0=oooo`030?l0ooooo`0000Koool006koool0
0`000?ooooooo`0Soooo00<0o`3oooooool00oooo`03o`00oooooooo03Ooool00`3o0?ooool00006
oooo001^oooo00<0003oooooool09?ooo`030?l0oooooooo00;oool00ol00?ooooooo`0foooo00@0
o`3ooooooooo0006oooo001^oooo00<0003oooooool09?ooo`030?l0oooooooo00;oool00ol00?oo
ooooo`0foooo00@0o`3ooooooooo0006oooo001^oooo00<0003oooooool09?ooo`030?l0oooooooo
00;oool00ol00?ooooooo`0foooo00@0o`3ooooooooo0006oooo001^oooo00<0003oooooool09?oo
o`030?l0oooooooo00?oool00ol00?ooooooo`0eoooo00@0o`3ooooooooo0006oooo001^oooo00<0
003oooooool09?ooo`030?l0oooooooo00?oool00ol00?ooooooo`0eoooo00@0o`3ooooooooo0006
oooo001^oooo00<0003oooooool09Oooo`030?l0oooooooo00;oool00ol00?ooooooo`0doooo00D0
o`3ooooooooooooo00001_ooo`00K_ooo`030000oooooooo02Goool00`3o0?ooooooo`02oooo00?o
003oooooool0=?ooo`050?l0ooooooooooooo`0000Koool006koool200009_ooo`030?l0oooooooo
00?oool00ol00?ooooooo`0coooo00D0o`3ooooooooooooo00001_ooo`00K_ooo`030000oooooooo
02Goool00`3o0?ooooooo`03oooo00?o003oooooool0<oooo`040?l0ooooooooo`001oooo`00K_oo
o`030000oooooooo02Goool00`3o0?ooooooo`03oooo00?o003oooooool0<oooo`040?l0oooooooo
o`001oooo`00K_ooo`030000oooooooo02Goool00`3o0?ooooooo`03oooo00?o003oooooool0<_oo
o`050?l0ooooooooooooo`0000Ooool006koool00`000?ooooooo`0Voooo00<0o`3oooooool00_oo
o`03o`00oooooooo03;oool01@3o0?ooooooooooool00007oooo001^oooo00<0003oooooool09_oo
o`030?l0oooooooo00?oool00ol00?ooooooo`0aoooo00D0o`3ooooooooooooo00001oooo`00K_oo
o`030000oooooooo02Koool00`3o0?ooooooo`03oooo00?o003oooooool0<Oooo`050?l0oooooooo
ooooo`0000Ooool006koool00`000?ooooooo`0Voooo00<0o`3oooooool00oooo`03o`00oooooooo
033oool00`3o0?ooooooo`02oooo00?o003oooooool01Oooo`00K_ooo`030000oooooooo02Koool0
0`3o0?ooooooo`03oooo00?o003oooooool0<?ooo`030?l0oooooooo00;oool00ol00?ooooooo`05
oooo001^oooo00<0003oooooool09oooo`030?l0oooooooo00?oool00ol00?ooooooo`0_oooo00<0
o`3oooooool00_ooo`03o`00oooooooo00Goool006koool00`000?ooooooo`0Woooo00<0o`3ooooo
ool00oooo`03o`00oooooooo02ooool00`3o0?ooooooo`02oooo00?o003oooooool01Oooo`00K_oo
o`030000oooooooo02Ooool00`3o0?ooooooo`03oooo00?o003oooooool0;oooo`030?l0oooooooo
00;oool00ol00?ooooooo`05oooo001^oooo00<0003oooooool09oooo`030?l0oooooooo00?oool0
0ol00?ooooooo`0^oooo00<0o`3oooooool00oooo`03o`00oooooooo00Goool006koool00`000?oo
ooooo`0Woooo00<0o`3oooooool00oooo`03o`00oooooooo02koool00`3o0?ooooooo`03oooo00?o
003oooooool01Oooo`00K_ooo`030000oooooooo02Soool00`3o0?ooooooo`03oooo00?o003ooooo
ool0;Oooo`030?l0oooooooo00?oool00ol00?ooooooo`05oooo001Yoooo0`0000;oool00`000?oo
ooooo`0Xoooo00<0o`3oooooool00oooo`03o`00oooooooo02goool00`3o0?ooooooo`03oooo00?o
003oooooool01Oooo`00J_ooo`050000oooooooooooo000002[oool00`3o0?ooooooo`03oooo00?o
003oooooool0;Oooo`030?l0oooooooo00?oool00ol00?ooooooo`05oooo001Xoooo100000;oool3
0000:?ooo`030?l0oooooooo00?oool00ol00?ooooooo`0/oooo00<0o`3oooooool00oooo`03o`00
oooooooo00Koool006Soool00`000?ooo`000003oooo00<0003oooooool0:?ooo`030?l0oooooooo
00Coool00ol00?ooooooo`0[oooo00<0o`3oooooool00oooo`03o`00oooooooo00Koool006Woool2
00000oooo`030000oooooooo02Woool00`3o0?ooooooo`03oooo00?o003oooooool0:oooo`030?l0
oooooooo00?oool00ol00?ooooooo`06oooo001Zoooo00D0003oooooooooool00000:oooo`030?l0
oooooooo00?oool00ol00?ooooooo`0[oooo00<0o`3oooooool00oooo`03o`00oooooooo00Koool0
06koool00`000?ooooooo`0Yoooo00<0o`3oooooool00oooo`03o`00oooooooo02[oool00`3o0?oo
ooooo`04oooo00?o003oooooool01_ooo`00K_ooo`030000oooooooo02Woool00`3o0?ooooooo`04
oooo00?o003oooooool0:Oooo`030?l0oooooooo00Coool00ol00?ooooooo`06oooo001^oooo00<0
003oooooool0:_ooo`030?l0oooooooo00?oool00ol00?ooooooo`0Yoooo00<0o`3oooooool01?oo
o`03o`00oooooooo00Koool006koool00`000?ooooooo`0Zoooo00<0o`3oooooool00oooo`03o`00
oooooooo02Woool00`3o0?ooooooo`04oooo00?o003oooooool01_ooo`00K_ooo`030000oooooooo
02[oool00`3o0?ooooooo`03oooo00?o003oooooool0:?ooo`030?l0oooooooo00Goool00ol00?oo
ooooo`06oooo001^oooo00<0003oooooool0:_ooo`030?l0oooooooo00?oool00ol00?ooooooo`0X
oooo00<0o`3oooooool01Oooo`03o`00oooooooo00Koool006koool00`000?ooooooo`0[oooo00<0
o`3oooooool00oooo`03o`00oooooooo02Ooool00`3o0?ooooooo`05oooo00?o003oooooool01_oo
o`00K_ooo`030000oooooooo02_oool00`3o0?ooooooo`03oooo00?o003oooooool09oooo`030?l0
oooooooo00Goool00ol00?ooooooo`06oooo001^oooo00<0003oooooool0:oooo`030?l0oooooooo
00?oool00ol00?ooooooo`0Voooo00<0o`3oooooool01_ooo`03o`00oooooooo00Koool006koool0
0`000?ooooooo`0[oooo00<0o`3oooooool00oooo`03o`00oooooooo02Koool00`3o0?ooooooo`06
oooo00?o003oooooool01_ooo`00K_ooo`030000oooooooo02coool00`3o0?ooooooo`03oooo00?o
003oooooool09Oooo`030?l0oooooooo00Koool00ol00?ooooooo`06oooo001^oooo00<0003ooooo
ool0;?ooo`030?l0oooooooo00?oool00ol00?ooooooo`0Uoooo00<0o`3oooooool01_ooo`03o`00
oooooooo00Koool006koool00`000?ooooooo`0/oooo00<0o`3oooooool00oooo`03o`00oooooooo
02Coool00`3o0?ooooooo`06oooo00?o003oooooool01oooo`00K_ooo`030000oooooooo02coool0
0`3o0?ooooooo`03oooo00?o003oooooool09?ooo`030?l0oooooooo00Koool00ol00?ooooooo`07
oooo001^oooo0P0002koool00`3o0?ooooooo`02oooo00?o003oooooool09?ooo`030?l0oooooooo
00Koool00ol00?ooooooo`07oooo001^oooo00<0003oooooool0;Oooo`030?l0oooooooo00?oool0
0ol00?ooooooo`0Soooo00<0o`3oooooool01_ooo`03o`00oooooooo00Ooool006koool00`000?oo
ooooo`0]oooo00<0o`3oooooool00oooo`03o`00oooooooo02;oool00`3o0?ooooooo`07oooo00?o
003oooooool01oooo`00K_ooo`030000oooooooo02goool00`3o0?ooooooo`03oooo00?o003ooooo
ool08_ooo`030?l0oooooooo00Ooool00ol00?ooooooo`07oooo001^oooo00<0003oooooool0;_oo
o`030?l0oooooooo00;oool00ol00?ooooooo`0Roooo00<0o`3oooooool01oooo`03o`00oooooooo
00Ooool006koool00`000?ooooooo`0^oooo00<0o`3oooooool00_ooo`03o`00oooooooo02;oool0
0`3o0?ooooooo`07oooo00?o003oooooool01oooo`00K_ooo`030000oooooooo02koool00`3o0?oo
ooooo`03oooo00?o003oooooool08?ooo`030?l0oooooooo00Soool00ol00?ooooooo`07oooo001^
oooo00<0003oooooool0;_ooo`030?l0oooooooo00?oool00ol00?ooooooo`0Poooo00<0o`3ooooo
ool02?ooo`03o`00oooooooo00Ooool006koool00`000?ooooooo`0^oooo00<0o`3oooooool00ooo
o`03o`00oooooooo023oool00`3o0?ooooooo`08oooo00?o003oooooool01oooo`00K_ooo`030000
oooooooo02ooool00`3o0?ooooooo`02oooo00?o003oooooool08?ooo`030?l0oooooooo00Soool0
0ol00?ooooooo`07oooo001^oooo00<0003oooooool0;oooo`030?l0oooooooo00?oool00ol00?oo
ooooo`0Noooo00<0o`3oooooool02Oooo`03o`00oooooooo00Ooool006koool00`000?ooooooo`0_
oooo00<0o`3oooooool00oooo`03o`00oooooooo01koool00`3o0?ooooooo`09oooo00?o003ooooo
ool01oooo`00K_ooo`030000oooooooo02ooool00`3o0?ooooooo`03oooo00?o003oooooool07_oo
o`030?l0oooooooo00Soool00ol00?ooooooo`08oooo001^oooo00<0003oooooool0<?ooo`030?l0
oooooooo00;oool00ol00?ooooooo`0Noooo00<0o`3oooooool02?ooo`03o`00oooooooo00Soool0
06koool00`000?ooooooo`0`oooo00<0o`3oooooool00_ooo`03o`00oooooooo01goool00`3o0?oo
ooooo`09oooo00?o003oooooool02?ooo`00K_ooo`030000oooooooo033oool00`3o0?ooooooo`03
oooo00?o003oooooool07?ooo`030?l0oooooooo00Woool00ol00?ooooooo`08oooo001^oooo00<0
003oooooool0<?ooo`030?l0oooooooo00?oool00ol00?ooooooo`0Loooo00<0o`3oooooool02Ooo
o`03o`00oooooooo00Soool006koool20000<_ooo`030?l0oooooooo00;oool00ol00?ooooooo`0K
oooo00<0o`3oooooool02_ooo`03o`00oooooooo00Soool006koool00`000?ooooooo`0aoooo00<0
o`3oooooool00_ooo`03o`00oooooooo01_oool00`3o0?ooooooo`0:oooo00?o003oooooool02?oo
o`00K_ooo`030000oooooooo037oool00`3o0?ooooooo`02oooo00?o003oooooool06oooo`030?l0
oooooooo00[oool00ol00?ooooooo`08oooo001^oooo00<0003oooooool0<Oooo`030?l0oooooooo
00?oool00ol00?ooooooo`0Ioooo00<0o`3oooooool02oooo`03o`00oooooooo00Soool006koool0
0`000?ooooooo`0boooo00<0o`3oooooool00_ooo`03o`00oooooooo01Woool00`3o0?ooooooo`0;
oooo00?o003oooooool02?ooo`00K_ooo`030000oooooooo03;oool00`3o0?ooooooo`02oooo00?o
003oooooool06?ooo`030?l0oooooooo00coool00ol00?ooooooo`08oooo001^oooo00<0003ooooo
ool0<_ooo`030?l0oooooooo00;oool00ol00?ooooooo`0Hoooo00<0o`3oooooool02oooo`03o`00
oooooooo00Woool006koool00`000?ooooooo`0boooo00<0o`3oooooool00_ooo`03o`00oooooooo
01Soool00`3o0?ooooooo`0;oooo00?o003oooooool02Oooo`00K_ooo`030000oooooooo03?oool0
0`3o0?ooooooo`02oooo00?o003oooooool05_ooo`030?l0oooooooo00coool00ol00?ooooooo`09
oooo001^oooo00<0003oooooool0<oooo`030?l0oooooooo00;oool00ol00?ooooooo`0Foooo00<0
o`3oooooool03?ooo`03o`00oooooooo00Woool006koool00`000?ooooooo`0coooo00<0o`3ooooo
ool00_ooo`03o`00oooooooo01Koool00`3o0?ooooooo`0<oooo00?o003oooooool02Oooo`00K_oo
o`030000oooooooo03Coool01@3o0?ooooooooooool0000Goooo00<0o`3oooooool03Oooo`03o`00
oooooooo00Woool006koool00`000?ooooooo`0doooo00D0o`3ooooooooooooo00005oooo`030?l0
oooooooo00goool00ol00?ooooooo`09oooo001^oooo00<0003oooooool0=?ooo`030?l0oooooooo
00;oool00ol00?ooooooo`0Coooo00<0o`3oooooool03_ooo`03o`00oooooooo00Woool006koool0
0`000?ooooooo`0eoooo00D0o`3ooooooooooooo00005Oooo`030?l0oooooooo00koool00ol00?oo
ooooo`09oooo001^oooo00<0003oooooool0=Oooo`050?l0ooooooooooooo`0001Goool00`3o0?oo
ooooo`0>oooo00?o003oooooool02Oooo`00K_ooo`030000oooooooo03Koool0103o0?ooooooool0
01Coool00`3o0?ooooooo`0?oooo00?o003oooooool02Oooo`00K_ooo`030000oooooooo03Koool0
1@3o0?ooooooooooool0000Coooo00<0o`3oooooool03_ooo`03o`00oooooooo00[oool006koool2
0000=oooo`050?l0ooooooooooooo`0001?oool00`3o0?ooooooo`0>oooo00?o003oooooool02_oo
o`00K_ooo`030000oooooooo03Ooool0103o0?ooooooool001;oool00`3o0?ooooooo`0?oooo00?o
003oooooool02_ooo`00K_ooo`030000oooooooo03Ooool0103o0?ooooooool001;oool00`3o0?oo
ooooo`0?oooo00?o003oooooool02_ooo`00K_ooo`030000oooooooo03Ooool0103o0?ooooooool0
017oool00`3o0?ooooooo`0@oooo00?o003oooooool02_ooo`00K_ooo`030000oooooooo03Soool0
103o0?ooooooool0013oool00`3o0?ooooooo`0@oooo00?o003oooooool02_ooo`00K_ooo`030000
oooooooo03Soool0103o0?ooooooool0013oool00`3o0?ooooooo`0@oooo00?o003oooooool02_oo
o`00K_ooo`030000oooooooo03Woool00`3o0?ooool0000?oooo00<0o`3oooooool04Oooo`03o`00
oooooooo00[oool006koool00`000?ooooooo`0ioooo00<0o`3ooooo00003oooo`030?l0oooooooo
017oool00ol00?ooooooo`0:oooo001^oooo00<0003oooooool0>_ooo`030?l0o`00oooo00goool0
0`3o0?ooooooo`0Boooo00?o003oooooool02_ooo`00K_ooo`030000oooooooo03[oool00`3o0?oo
ool0000=oooo00<0o`3oooooool04_ooo`03o`00oooooooo00[oool006koool00`000?ooooooo`0k
oooo00<0o`3o003oool02oooo`030?l0oooooooo01;oool00ol00?ooooooo`0;oooo001^oooo00<0
003oooooool0>oooo`030?l0o`00oooo00_oool00`3o0?ooooooo`0Boooo00?o003oooooool02ooo
o`00K_ooo`030000oooooooo03coool00`3o0?ooooooo`09oooo00<0o`3oooooool04oooo`03o`00
oooooooo00_oool006koool00`000?ooooooo`0loooo00<0o`3oooooool02?ooo`030?l0oooooooo
01Coool00ol00?ooooooo`0;oooo001^oooo00<0003oooooool0?Oooo`030?l0oooooooo00Koool0
0`3o0?ooooooo`0Eoooo00?o003oooooool02oooo`00J?ooo`800004oooo00<0003oooooool0?Ooo
o`03o`000?l0oooo00Goool00`3o0?ooooooo`0Foooo00?o003oooooool02oooo`00J?ooo`030000
oooo000000?oool00`000?ooooooo`0moooo00Co003oool0o`00o`02oooo0P3o01Woool00ol00?oo
ooooo`0;oooo001Xoooo00<0003oool000000oooo`<0000moooo00?o003oooooool00`3o01_oool0
0ol00?ooooooo`0;oooo001Xoooo0P0000Coool00`000?ooooooo`0moooo00?o003oooooool07_oo
o`03o`00oooooooo00_oool006Soool00`000?ooooooo`03oooo00<0003oooooool0?_ooo`03o`00
oooooooo01coool00ol00?ooooooo`0<oooo001Yoooo0P0000?oool00`000?ooooooo`0noooo00?o
003oooooool07?ooo`03o`00oooooooo00coool006koool00`000?ooooooo`0noooo00?o003ooooo
ool07?ooo`03o`00oooooooo00coool006koool00`000?ooooooo`0noooo00?o003oooooool07?oo
o`03o`00oooooooo00coool006koool00`000?ooooooo`0noooo00?o003oooooool07?ooo`03o`00
oooooooo00coool006koool00`000?ooooooo`0ooooo00?o003oooooool06oooo`03o`00oooooooo
00coool006koool00`000?ooooooo`0ooooo00?o003oooooool06_ooo`03o`00oooooooo00goool0
06koool00`000?ooooooo`0ooooo00?o003oooooool06_ooo`03o`00oooooooo00goool006koool0
0`000?ooooooo`0ooooo00?o003oooooool06_ooo`03o`00oooooooo00goool006koool00`000?oo
ooooo`0ooooo00?o003oooooool06_ooo`03o`00oooooooo00goool006koool00`000?ooooooo`10
oooo00?o003oooooool06Oooo`03o`00oooooooo00goool006koool00`000?ooooooo`10oooo00?o
003oooooool06Oooo`03o`00oooooooo00goool006koool00`000?ooooooo`10oooo00?o003ooooo
ool06?ooo`03o`00oooooooo00koool006koool00`000?ooooooo`10oooo00?o003oooooool06?oo
o`03o`00oooooooo00koool006koool00`000?ooooooo`11oooo00?o003oooooool05oooo`03o`00
oooooooo00koool006koool20000@_ooo`03o`00oooooooo01Ooool00ol00?ooooooo`0>oooo001^
oooo00<0003oooooool0@Oooo`03o`00oooooooo01Ooool00ol00?ooooooo`0>oooo001^oooo00<0
003oooooool0@Oooo`03o`00oooooooo01Ooool00ol00?ooooooo`0>oooo001^oooo00<0003ooooo
ool0@_ooo`03o`00oooooooo01Goool00ol00?ooooooo`0?oooo001^oooo00<0003oooooool0@_oo
o`03o`00oooooooo01Goool00ol00?ooooooo`0?oooo001^oooo00<0003oooooool0@_ooo`03o`00
oooooooo01Goool00ol00?ooooooo`0?oooo001^oooo00<0003oooooool0@_ooo`03o`00oooooooo
01Goool00ol00?ooooooo`0?oooo001^oooo00<0003oooooool0@oooo`03o`00oooooooo01Coool0
0ol00?ooooooo`0?oooo001^oooo00<0003oooooool0@oooo`03o`00oooooooo01Coool00ol00?oo
ooooo`0?oooo001^oooo00<0003oooooool0@oooo`03o`00oooooooo01?oool00ol00?ooooooo`0@
oooo001^oooo00<0003oooooool0@oooo`03o`00oooooooo01?oool00ol00?ooooooo`0@oooo001^
oooo00<0003oooooool0A?ooo`03o`00oooooooo01;oool00ol00?ooooooo`0@oooo001^oooo00<0
003oooooool0A?ooo`03o`00oooooooo01;oool00ol00?ooooooo`0@oooo001^oooo00<0003ooooo
ool0A?ooo`03o`00oooooooo01;oool00ol00?ooooooo`0@oooo001^oooo00<0003oooooool0AOoo
o`03o`00oooooooo017oool00ol00?ooooooo`0@oooo001^oooo00<0003oooooool0AOooo`03o`00
oooooooo013oool00ol00?ooooooo`0Aoooo001^oooo00<0003oooooool0AOooo`03o`00oooooooo
013oool00ol00?ooooooo`0Aoooo001^oooo00<0003oooooool0AOooo`03o`00oooooooo013oool0
0ol00?ooooooo`0Aoooo001^oooo0P0004Ooool00ol00?ooooooo`0?oooo00?o003oooooool04Ooo
o`00K_ooo`030000oooooooo04Koool00ol00?ooooooo`0>oooo00?o003oooooool04_ooo`00K_oo
o`030000oooooooo04Koool00ol00?ooooooo`0>oooo00?o003oooooool04_ooo`00K_ooo`030000
oooooooo04Ooool00ol00?ooooooo`0=oooo00?o003oooooool04_ooo`00K_ooo`030000oooooooo
04Ooool00ol00?ooooooo`0=oooo00?o003oooooool04_ooo`00K_ooo`030000oooooooo04Soool0
0ol00?ooooooo`0<oooo00?o003oooooool04_ooo`00K_ooo`030000oooooooo04Soool00ol00?oo
ooooo`0;oooo00?o003oooooool04oooo`00K_ooo`030000oooooooo04Woool00ol00?ooooooo`0:
oooo00?o003oooooool04oooo`00K_ooo`030000oooooooo04Woool00ol00?ooooooo`0:oooo00?o
003oooooool04oooo`00K_ooo`030000oooooooo04[oool00ol00?ooooooo`08oooo00?o003ooooo
ool05?ooo`00K_ooo`030000oooooooo04_oool00ol00?ooooooo`07oooo00?o003oooooool05?oo
o`00K_ooo`030000oooooooo04_oool00ol00?ooooooo`06oooo00?o003oooooool05Oooo`00K_oo
o`030000oooooooo04coool00ol00?ooooooo`05oooo00?o003oooooool05Oooo`00K_ooo`030000
oooooooo04coool00ol00?ooooooo`04oooo00?o003oooooool05_ooo`00K_ooo`030000oooooooo
04goool00ol00?ooooooo`02oooo00?o003oooooool05oooo`00K_ooo`030000oooooooo04goool2
o`000oooo`03o`00oooooooo01Ooool006koool00`000?ooooooo`1>oooo1?l001[oool006koool2
0000KOooo`00K_ooo`030000oooooooo06coool006koool00`000?ooooooo`1/oooo001^oooo00<0
003oooooool0K?ooo`00K_ooo`030000oooooooo06coool006koool00`000?ooooooo`1/oooo001^
oooo00<0003oooooool0K?ooo`00\
\>"],
  ImageRangeCache->{{{137.688, 358.563}, {686.313, 399.313}} -> {-7.1126, 
  10.8891, 0.0286216, 0.0286216}}]
}, Open  ]],

Cell["\<\
\tComo puede observarse en la gr\[AAcute]fica, la aproximaci\[OAcute]n es \
mala en el \[UAcute]ltimo intervalo considerado. Puede intentarse, \
v\[EAcute]ase el ejercicio 1, mejorar la aproximaci\[OAcute]n en el \
\[UAcute]ltimo intervalo.\
\>", "Text",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Ejercicios.", "Section",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "  ",
  StyleBox["Ejercicio  1:",
    FontVariations->{"Underline"->True}],
  " "
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
\tRepetir el ejemplo 2, dividiendo el intervalo [-3,3] en 10 partes \
iguales.\
\>", "Text",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "  ",
  StyleBox["Ejercicio  2:",
    FontVariations->{"Underline"->True}],
  " "
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\tEscribir una funci\[OAcute]n an\[AAcute]loga a la funci\[OAcute]n ",
  StyleBox["Espline",
    FontWeight->"Bold"],
  " ya definida que calcule los polinomios c\[UAcute]bicos asociados a ",
  StyleBox["los ",
    FontWeight->"Bold"],
  "s",
  StyleBox["plines de frontera fija. ",
    FontWeight->"Bold"],
  "Dichos splines se definen sustituyendo la condici\[OAcute]n 6) del sistema \
que define el spline natural por la condici\[OAcute]n siguiente:\n",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(En\ la\ frontera, \ 
      las\ \ derivadas\ coinciden\ con\ la\ derivada\ de\ la\ funci\[OAcute]n
        \ \(f(x)\), \ es\ decir, \ \ \n
      \(\((S')\)\_0\) \((x\_0)\) = f' \((x\_0)\), \ 
      \(\((S')\)\_\(n - 1\)\) \((x\_n)\) = f' \((x\_n)\)\ \)\)]]]
}], "Text",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "  ",
  StyleBox["Ejercicio  3:",
    FontVariations->{"Underline"->True}],
  " "
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell[TextData[{
  "\tAplicar la funci\[OAcute]n definida anteriormente para calcular el \
spline de frontera fija asociado a la funci\[OAcute]n ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\(\[ExponentialE]\^x\) \(sen(x)\)\ \)\)]]],
  " en el intervalo [-3,3] , dividiendo el intervalo considerado en 10 partes \
iguales."
}], "Text",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Datos del grupo.", "Section",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True],

Cell["\<\
\tNombre de los alumnos del grupo: 

\tGrupo: 

\tOrdenador utilizado:
\
\>", "Text",
  CellMargins->{{17, Inherited}, {Inherited, Inherited}},
  Evaluatable->False,
  CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
  AspectRatioFixed->True]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{759, 482},
WindowMargins->{{0, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{8, 8},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, 
      "Pr\[AAcute]ctica n\.ba 6"}, {
    "Pr\[AAcute]ctica n\.ba 6", Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PageFooters->{{
  Inherited, 
      "Departamento de Matem\[AAcute]tica Aplicada.   ETSII de B\[EAcute]jar",
       Inherited}, {
    Inherited, 
      "Departamento de Matem\[AAcute]tica Aplicada.   ETSII de B\[EAcute]jar",
       Inherited}},
PageFooterLines->{True, True},
PrintingOptions->{"PrintingMargins"->{{108, 86.375}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FacingPages"->True,
"GraphicsPrintingFormat"->"RenderInFrontEnd"},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 409, 13, 146, "Title"],
Cell[2121, 64, 387, 14, 147, "Subtitle"],
Cell[2511, 80, 428, 10, 99, "Text"],
Cell[2942, 92, 208, 4, 46, "Section"],
Cell[3153, 98, 671, 12, 83, "Text"],
Cell[3827, 112, 219, 4, 46, "Section"],
Cell[4049, 118, 1957, 49, 194, "Text"],
Cell[6009, 169, 1185, 25, 111, "Text"],
Cell[7197, 196, 1975, 54, 230, "Text"],
Cell[9175, 252, 926, 22, 84, "Text"],
Cell[10104, 276, 666, 18, 54, "Text"],
Cell[10773, 296, 126, 3, 38, "Input"],
Cell[10902, 301, 572, 15, 54, "Text"],
Cell[11477, 318, 1325, 24, 264, "Input"],
Cell[12805, 344, 563, 12, 83, "Text"],
Cell[13371, 358, 309, 10, 26, "Text"],
Cell[13683, 370, 304, 9, 40, "Text"],
Cell[13990, 381, 334, 7, 40, "Text"],

Cell[CellGroupData[{
Cell[14349, 392, 77, 1, 22, "Input"],
Cell[14429, 395, 298, 6, 66, "Output"]
}, Open  ]],
Cell[14742, 404, 312, 7, 40, "Text"],

Cell[CellGroupData[{
Cell[15079, 415, 58, 1, 22, "Input"],
Cell[15140, 418, 66, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15243, 424, 58, 1, 22, "Input"],
Cell[15304, 427, 132, 3, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15473, 435, 58, 1, 22, "Input"],
Cell[15534, 438, 144, 4, 45, "Output"]
}, Open  ]],
Cell[15693, 445, 290, 7, 26, "Text"],
Cell[15986, 454, 120, 2, 45, "Input"],
Cell[16109, 458, 206, 3, 57, "Input"],
Cell[16318, 463, 231, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[16574, 471, 125, 2, 33, "Input"],
Cell[16702, 475, 14850, 424, 139, 4085, 287, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[31567, 902, 186, 4, 26, "Text"],
Cell[31756, 908, 309, 10, 26, "Text"],
Cell[32068, 920, 418, 9, 40, "Text"],
Cell[32489, 931, 242, 4, 26, "Text"],
Cell[32734, 937, 68, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[32827, 942, 65, 1, 22, "Input"],
Cell[32895, 945, 16867, 456, 185, 4068, 294, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[49777, 1404, 312, 7, 40, "Text"],

Cell[CellGroupData[{
Cell[50114, 1415, 99, 2, 22, "Input"],
Cell[50216, 1419, 647, 15, 50, "Output"]
}, Open  ]],
Cell[50878, 1437, 225, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[51128, 1445, 85, 1, 22, "Input"],
Cell[51216, 1448, 371, 10, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51624, 1463, 80, 1, 22, "Input"],
Cell[51707, 1466, 247, 5, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51991, 1476, 64, 1, 22, "Input"],
Cell[52058, 1479, 1380, 25, 100, "Output"]
}, Open  ]],
Cell[53453, 1507, 278, 7, 26, "Text"],
Cell[53734, 1516, 71, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[53830, 1521, 59, 1, 22, "Input"],
Cell[53892, 1524, 209, 5, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54138, 1534, 59, 1, 22, "Input"],
Cell[54200, 1537, 208, 5, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54445, 1547, 59, 1, 22, "Input"],
Cell[54507, 1550, 200, 4, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54744, 1559, 59, 1, 22, "Input"],
Cell[54806, 1562, 214, 4, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55057, 1571, 59, 1, 22, "Input"],
Cell[55119, 1574, 196, 4, 38, "Output"]
}, Open  ]],
Cell[55330, 1581, 187, 3, 81, "Input"],
Cell[55520, 1586, 241, 4, 26, "Text"],
Cell[55764, 1592, 486, 10, 69, "Input"],
Cell[56253, 1604, 454, 9, 54, "Text"],

Cell[CellGroupData[{
Cell[56732, 1617, 166, 3, 45, "Input"],
Cell[56901, 1622, 29604, 681, 296, 5424, 378, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[86520, 2306, 432, 9, 52, "Text"],

Cell[CellGroupData[{
Cell[86977, 2319, 198, 4, 53, "Section"],

Cell[CellGroupData[{
Cell[87200, 2327, 313, 10, 33, "Text"],
Cell[87516, 2339, 270, 7, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87823, 2351, 313, 10, 33, "Text"],
Cell[88139, 2363, 965, 22, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89141, 2390, 313, 10, 33, "Text"],
Cell[89457, 2402, 512, 11, 52, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90018, 2419, 203, 4, 53, "Section"],
Cell[90224, 2425, 263, 11, 128, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

